# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.31
#
# Don't modify this file, modify the SWIG interface instead.

package Math::GSL::Const;
require Exporter;
require DynaLoader;
@ISA = qw(Exporter DynaLoader);
package Math::GSL::Constc;
bootstrap Math::GSL::Const;
package Math::GSL::Const;
@EXPORT = qw( );

# ---------- BASE METHODS -------------

package Math::GSL::Const;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package Math::GSL::Const;

*gsl_max = *Math::GSL::Constc::gsl_max;
*gsl_min = *Math::GSL::Constc::gsl_min;

############# Class : Math::GSL::Const::gsl_function_struct ##############

package Math::GSL::Const::gsl_function_struct;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Math::GSL::Const );
%OWNER = ();
%ITERATORS = ();
*swig_function_get = *Math::GSL::Constc::gsl_function_struct_function_get;
*swig_function_set = *Math::GSL::Constc::gsl_function_struct_function_set;
*swig_params_get = *Math::GSL::Constc::gsl_function_struct_params_get;
*swig_params_set = *Math::GSL::Constc::gsl_function_struct_params_set;
sub new {
    my $pkg = shift;
    my $self = Math::GSL::Constc::new_gsl_function_struct(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Math::GSL::Constc::delete_gsl_function_struct($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Math::GSL::Const::gsl_function_fdf_struct ##############

package Math::GSL::Const::gsl_function_fdf_struct;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Math::GSL::Const );
%OWNER = ();
%ITERATORS = ();
*swig_f_get = *Math::GSL::Constc::gsl_function_fdf_struct_f_get;
*swig_f_set = *Math::GSL::Constc::gsl_function_fdf_struct_f_set;
*swig_df_get = *Math::GSL::Constc::gsl_function_fdf_struct_df_get;
*swig_df_set = *Math::GSL::Constc::gsl_function_fdf_struct_df_set;
*swig_fdf_get = *Math::GSL::Constc::gsl_function_fdf_struct_fdf_get;
*swig_fdf_set = *Math::GSL::Constc::gsl_function_fdf_struct_fdf_set;
*swig_params_get = *Math::GSL::Constc::gsl_function_fdf_struct_params_get;
*swig_params_set = *Math::GSL::Constc::gsl_function_fdf_struct_params_set;
sub new {
    my $pkg = shift;
    my $self = Math::GSL::Constc::new_gsl_function_fdf_struct(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Math::GSL::Constc::delete_gsl_function_fdf_struct($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


############# Class : Math::GSL::Const::gsl_function_vec_struct ##############

package Math::GSL::Const::gsl_function_vec_struct;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( Math::GSL::Const );
%OWNER = ();
%ITERATORS = ();
*swig_function_get = *Math::GSL::Constc::gsl_function_vec_struct_function_get;
*swig_function_set = *Math::GSL::Constc::gsl_function_vec_struct_function_set;
*swig_params_get = *Math::GSL::Constc::gsl_function_vec_struct_params_get;
*swig_params_set = *Math::GSL::Constc::gsl_function_vec_struct_params_set;
sub new {
    my $pkg = shift;
    my $self = Math::GSL::Constc::new_gsl_function_vec_struct(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        Math::GSL::Constc::delete_gsl_function_vec_struct($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


# ------- VARIABLE STUBS --------

package Math::GSL::Const;

*M_E = *Math::GSL::Constc::M_E;
*M_LOG2E = *Math::GSL::Constc::M_LOG2E;
*M_LOG10E = *Math::GSL::Constc::M_LOG10E;
*M_SQRT2 = *Math::GSL::Constc::M_SQRT2;
*M_SQRT1_2 = *Math::GSL::Constc::M_SQRT1_2;
*M_SQRT3 = *Math::GSL::Constc::M_SQRT3;
*M_PI = *Math::GSL::Constc::M_PI;
*M_PI_2 = *Math::GSL::Constc::M_PI_2;
*M_PI_4 = *Math::GSL::Constc::M_PI_4;
*M_SQRTPI = *Math::GSL::Constc::M_SQRTPI;
*M_2_SQRTPI = *Math::GSL::Constc::M_2_SQRTPI;
*M_1_PI = *Math::GSL::Constc::M_1_PI;
*M_2_PI = *Math::GSL::Constc::M_2_PI;
*M_LN10 = *Math::GSL::Constc::M_LN10;
*M_LN2 = *Math::GSL::Constc::M_LN2;
*M_LNPI = *Math::GSL::Constc::M_LNPI;
*M_EULER = *Math::GSL::Constc::M_EULER;
*GSL_CONST_CGS_SPEED_OF_LIGHT = *Math::GSL::Constc::GSL_CONST_CGS_SPEED_OF_LIGHT;
*GSL_CONST_CGS_GRAVITATIONAL_CONSTANT = *Math::GSL::Constc::GSL_CONST_CGS_GRAVITATIONAL_CONSTANT;
*GSL_CONST_CGS_PLANCKS_CONSTANT_H = *Math::GSL::Constc::GSL_CONST_CGS_PLANCKS_CONSTANT_H;
*GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR = *Math::GSL::Constc::GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR;
*GSL_CONST_CGS_ASTRONOMICAL_UNIT = *Math::GSL::Constc::GSL_CONST_CGS_ASTRONOMICAL_UNIT;
*GSL_CONST_CGS_LIGHT_YEAR = *Math::GSL::Constc::GSL_CONST_CGS_LIGHT_YEAR;
*GSL_CONST_CGS_PARSEC = *Math::GSL::Constc::GSL_CONST_CGS_PARSEC;
*GSL_CONST_CGS_GRAV_ACCEL = *Math::GSL::Constc::GSL_CONST_CGS_GRAV_ACCEL;
*GSL_CONST_CGS_ELECTRON_VOLT = *Math::GSL::Constc::GSL_CONST_CGS_ELECTRON_VOLT;
*GSL_CONST_CGS_MASS_ELECTRON = *Math::GSL::Constc::GSL_CONST_CGS_MASS_ELECTRON;
*GSL_CONST_CGS_MASS_MUON = *Math::GSL::Constc::GSL_CONST_CGS_MASS_MUON;
*GSL_CONST_CGS_MASS_PROTON = *Math::GSL::Constc::GSL_CONST_CGS_MASS_PROTON;
*GSL_CONST_CGS_MASS_NEUTRON = *Math::GSL::Constc::GSL_CONST_CGS_MASS_NEUTRON;
*GSL_CONST_CGS_RYDBERG = *Math::GSL::Constc::GSL_CONST_CGS_RYDBERG;
*GSL_CONST_CGS_BOLTZMANN = *Math::GSL::Constc::GSL_CONST_CGS_BOLTZMANN;
*GSL_CONST_CGS_BOHR_MAGNETON = *Math::GSL::Constc::GSL_CONST_CGS_BOHR_MAGNETON;
*GSL_CONST_CGS_NUCLEAR_MAGNETON = *Math::GSL::Constc::GSL_CONST_CGS_NUCLEAR_MAGNETON;
*GSL_CONST_CGS_ELECTRON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_CGS_ELECTRON_MAGNETIC_MOMENT;
*GSL_CONST_CGS_PROTON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_CGS_PROTON_MAGNETIC_MOMENT;
*GSL_CONST_CGS_MOLAR_GAS = *Math::GSL::Constc::GSL_CONST_CGS_MOLAR_GAS;
*GSL_CONST_CGS_STANDARD_GAS_VOLUME = *Math::GSL::Constc::GSL_CONST_CGS_STANDARD_GAS_VOLUME;
*GSL_CONST_CGS_MINUTE = *Math::GSL::Constc::GSL_CONST_CGS_MINUTE;
*GSL_CONST_CGS_HOUR = *Math::GSL::Constc::GSL_CONST_CGS_HOUR;
*GSL_CONST_CGS_DAY = *Math::GSL::Constc::GSL_CONST_CGS_DAY;
*GSL_CONST_CGS_WEEK = *Math::GSL::Constc::GSL_CONST_CGS_WEEK;
*GSL_CONST_CGS_INCH = *Math::GSL::Constc::GSL_CONST_CGS_INCH;
*GSL_CONST_CGS_FOOT = *Math::GSL::Constc::GSL_CONST_CGS_FOOT;
*GSL_CONST_CGS_YARD = *Math::GSL::Constc::GSL_CONST_CGS_YARD;
*GSL_CONST_CGS_MILE = *Math::GSL::Constc::GSL_CONST_CGS_MILE;
*GSL_CONST_CGS_NAUTICAL_MILE = *Math::GSL::Constc::GSL_CONST_CGS_NAUTICAL_MILE;
*GSL_CONST_CGS_FATHOM = *Math::GSL::Constc::GSL_CONST_CGS_FATHOM;
*GSL_CONST_CGS_MIL = *Math::GSL::Constc::GSL_CONST_CGS_MIL;
*GSL_CONST_CGS_POINT = *Math::GSL::Constc::GSL_CONST_CGS_POINT;
*GSL_CONST_CGS_TEXPOINT = *Math::GSL::Constc::GSL_CONST_CGS_TEXPOINT;
*GSL_CONST_CGS_MICRON = *Math::GSL::Constc::GSL_CONST_CGS_MICRON;
*GSL_CONST_CGS_ANGSTROM = *Math::GSL::Constc::GSL_CONST_CGS_ANGSTROM;
*GSL_CONST_CGS_HECTARE = *Math::GSL::Constc::GSL_CONST_CGS_HECTARE;
*GSL_CONST_CGS_ACRE = *Math::GSL::Constc::GSL_CONST_CGS_ACRE;
*GSL_CONST_CGS_BARN = *Math::GSL::Constc::GSL_CONST_CGS_BARN;
*GSL_CONST_CGS_LITER = *Math::GSL::Constc::GSL_CONST_CGS_LITER;
*GSL_CONST_CGS_US_GALLON = *Math::GSL::Constc::GSL_CONST_CGS_US_GALLON;
*GSL_CONST_CGS_QUART = *Math::GSL::Constc::GSL_CONST_CGS_QUART;
*GSL_CONST_CGS_PINT = *Math::GSL::Constc::GSL_CONST_CGS_PINT;
*GSL_CONST_CGS_CUP = *Math::GSL::Constc::GSL_CONST_CGS_CUP;
*GSL_CONST_CGS_FLUID_OUNCE = *Math::GSL::Constc::GSL_CONST_CGS_FLUID_OUNCE;
*GSL_CONST_CGS_TABLESPOON = *Math::GSL::Constc::GSL_CONST_CGS_TABLESPOON;
*GSL_CONST_CGS_TEASPOON = *Math::GSL::Constc::GSL_CONST_CGS_TEASPOON;
*GSL_CONST_CGS_CANADIAN_GALLON = *Math::GSL::Constc::GSL_CONST_CGS_CANADIAN_GALLON;
*GSL_CONST_CGS_UK_GALLON = *Math::GSL::Constc::GSL_CONST_CGS_UK_GALLON;
*GSL_CONST_CGS_MILES_PER_HOUR = *Math::GSL::Constc::GSL_CONST_CGS_MILES_PER_HOUR;
*GSL_CONST_CGS_KILOMETERS_PER_HOUR = *Math::GSL::Constc::GSL_CONST_CGS_KILOMETERS_PER_HOUR;
*GSL_CONST_CGS_KNOT = *Math::GSL::Constc::GSL_CONST_CGS_KNOT;
*GSL_CONST_CGS_POUND_MASS = *Math::GSL::Constc::GSL_CONST_CGS_POUND_MASS;
*GSL_CONST_CGS_OUNCE_MASS = *Math::GSL::Constc::GSL_CONST_CGS_OUNCE_MASS;
*GSL_CONST_CGS_TON = *Math::GSL::Constc::GSL_CONST_CGS_TON;
*GSL_CONST_CGS_METRIC_TON = *Math::GSL::Constc::GSL_CONST_CGS_METRIC_TON;
*GSL_CONST_CGS_UK_TON = *Math::GSL::Constc::GSL_CONST_CGS_UK_TON;
*GSL_CONST_CGS_TROY_OUNCE = *Math::GSL::Constc::GSL_CONST_CGS_TROY_OUNCE;
*GSL_CONST_CGS_CARAT = *Math::GSL::Constc::GSL_CONST_CGS_CARAT;
*GSL_CONST_CGS_UNIFIED_ATOMIC_MASS = *Math::GSL::Constc::GSL_CONST_CGS_UNIFIED_ATOMIC_MASS;
*GSL_CONST_CGS_GRAM_FORCE = *Math::GSL::Constc::GSL_CONST_CGS_GRAM_FORCE;
*GSL_CONST_CGS_POUND_FORCE = *Math::GSL::Constc::GSL_CONST_CGS_POUND_FORCE;
*GSL_CONST_CGS_KILOPOUND_FORCE = *Math::GSL::Constc::GSL_CONST_CGS_KILOPOUND_FORCE;
*GSL_CONST_CGS_POUNDAL = *Math::GSL::Constc::GSL_CONST_CGS_POUNDAL;
*GSL_CONST_CGS_CALORIE = *Math::GSL::Constc::GSL_CONST_CGS_CALORIE;
*GSL_CONST_CGS_BTU = *Math::GSL::Constc::GSL_CONST_CGS_BTU;
*GSL_CONST_CGS_THERM = *Math::GSL::Constc::GSL_CONST_CGS_THERM;
*GSL_CONST_CGS_HORSEPOWER = *Math::GSL::Constc::GSL_CONST_CGS_HORSEPOWER;
*GSL_CONST_CGS_BAR = *Math::GSL::Constc::GSL_CONST_CGS_BAR;
*GSL_CONST_CGS_STD_ATMOSPHERE = *Math::GSL::Constc::GSL_CONST_CGS_STD_ATMOSPHERE;
*GSL_CONST_CGS_TORR = *Math::GSL::Constc::GSL_CONST_CGS_TORR;
*GSL_CONST_CGS_METER_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_CGS_METER_OF_MERCURY;
*GSL_CONST_CGS_INCH_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_CGS_INCH_OF_MERCURY;
*GSL_CONST_CGS_INCH_OF_WATER = *Math::GSL::Constc::GSL_CONST_CGS_INCH_OF_WATER;
*GSL_CONST_CGS_PSI = *Math::GSL::Constc::GSL_CONST_CGS_PSI;
*GSL_CONST_CGS_POISE = *Math::GSL::Constc::GSL_CONST_CGS_POISE;
*GSL_CONST_CGS_STOKES = *Math::GSL::Constc::GSL_CONST_CGS_STOKES;
*GSL_CONST_CGS_FARADAY = *Math::GSL::Constc::GSL_CONST_CGS_FARADAY;
*GSL_CONST_CGS_ELECTRON_CHARGE = *Math::GSL::Constc::GSL_CONST_CGS_ELECTRON_CHARGE;
*GSL_CONST_CGS_GAUSS = *Math::GSL::Constc::GSL_CONST_CGS_GAUSS;
*GSL_CONST_CGS_STILB = *Math::GSL::Constc::GSL_CONST_CGS_STILB;
*GSL_CONST_CGS_LUMEN = *Math::GSL::Constc::GSL_CONST_CGS_LUMEN;
*GSL_CONST_CGS_LUX = *Math::GSL::Constc::GSL_CONST_CGS_LUX;
*GSL_CONST_CGS_PHOT = *Math::GSL::Constc::GSL_CONST_CGS_PHOT;
*GSL_CONST_CGS_FOOTCANDLE = *Math::GSL::Constc::GSL_CONST_CGS_FOOTCANDLE;
*GSL_CONST_CGS_LAMBERT = *Math::GSL::Constc::GSL_CONST_CGS_LAMBERT;
*GSL_CONST_CGS_FOOTLAMBERT = *Math::GSL::Constc::GSL_CONST_CGS_FOOTLAMBERT;
*GSL_CONST_CGS_CURIE = *Math::GSL::Constc::GSL_CONST_CGS_CURIE;
*GSL_CONST_CGS_ROENTGEN = *Math::GSL::Constc::GSL_CONST_CGS_ROENTGEN;
*GSL_CONST_CGS_RAD = *Math::GSL::Constc::GSL_CONST_CGS_RAD;
*GSL_CONST_CGS_SOLAR_MASS = *Math::GSL::Constc::GSL_CONST_CGS_SOLAR_MASS;
*GSL_CONST_CGS_BOHR_RADIUS = *Math::GSL::Constc::GSL_CONST_CGS_BOHR_RADIUS;
*GSL_CONST_CGS_NEWTON = *Math::GSL::Constc::GSL_CONST_CGS_NEWTON;
*GSL_CONST_CGS_DYNE = *Math::GSL::Constc::GSL_CONST_CGS_DYNE;
*GSL_CONST_CGS_JOULE = *Math::GSL::Constc::GSL_CONST_CGS_JOULE;
*GSL_CONST_CGS_ERG = *Math::GSL::Constc::GSL_CONST_CGS_ERG;
*GSL_CONST_CGS_STEFAN_BOLTZMANN_CONSTANT = *Math::GSL::Constc::GSL_CONST_CGS_STEFAN_BOLTZMANN_CONSTANT;
*GSL_CONST_CGS_THOMSON_CROSS_SECTION = *Math::GSL::Constc::GSL_CONST_CGS_THOMSON_CROSS_SECTION;
*GSL_CONST_CGSM_SPEED_OF_LIGHT = *Math::GSL::Constc::GSL_CONST_CGSM_SPEED_OF_LIGHT;
*GSL_CONST_CGSM_GRAVITATIONAL_CONSTANT = *Math::GSL::Constc::GSL_CONST_CGSM_GRAVITATIONAL_CONSTANT;
*GSL_CONST_CGSM_PLANCKS_CONSTANT_H = *Math::GSL::Constc::GSL_CONST_CGSM_PLANCKS_CONSTANT_H;
*GSL_CONST_CGSM_PLANCKS_CONSTANT_HBAR = *Math::GSL::Constc::GSL_CONST_CGSM_PLANCKS_CONSTANT_HBAR;
*GSL_CONST_CGSM_ASTRONOMICAL_UNIT = *Math::GSL::Constc::GSL_CONST_CGSM_ASTRONOMICAL_UNIT;
*GSL_CONST_CGSM_LIGHT_YEAR = *Math::GSL::Constc::GSL_CONST_CGSM_LIGHT_YEAR;
*GSL_CONST_CGSM_PARSEC = *Math::GSL::Constc::GSL_CONST_CGSM_PARSEC;
*GSL_CONST_CGSM_GRAV_ACCEL = *Math::GSL::Constc::GSL_CONST_CGSM_GRAV_ACCEL;
*GSL_CONST_CGSM_ELECTRON_VOLT = *Math::GSL::Constc::GSL_CONST_CGSM_ELECTRON_VOLT;
*GSL_CONST_CGSM_MASS_ELECTRON = *Math::GSL::Constc::GSL_CONST_CGSM_MASS_ELECTRON;
*GSL_CONST_CGSM_MASS_MUON = *Math::GSL::Constc::GSL_CONST_CGSM_MASS_MUON;
*GSL_CONST_CGSM_MASS_PROTON = *Math::GSL::Constc::GSL_CONST_CGSM_MASS_PROTON;
*GSL_CONST_CGSM_MASS_NEUTRON = *Math::GSL::Constc::GSL_CONST_CGSM_MASS_NEUTRON;
*GSL_CONST_CGSM_RYDBERG = *Math::GSL::Constc::GSL_CONST_CGSM_RYDBERG;
*GSL_CONST_CGSM_BOLTZMANN = *Math::GSL::Constc::GSL_CONST_CGSM_BOLTZMANN;
*GSL_CONST_CGSM_BOHR_MAGNETON = *Math::GSL::Constc::GSL_CONST_CGSM_BOHR_MAGNETON;
*GSL_CONST_CGSM_NUCLEAR_MAGNETON = *Math::GSL::Constc::GSL_CONST_CGSM_NUCLEAR_MAGNETON;
*GSL_CONST_CGSM_ELECTRON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_CGSM_ELECTRON_MAGNETIC_MOMENT;
*GSL_CONST_CGSM_PROTON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_CGSM_PROTON_MAGNETIC_MOMENT;
*GSL_CONST_CGSM_MOLAR_GAS = *Math::GSL::Constc::GSL_CONST_CGSM_MOLAR_GAS;
*GSL_CONST_CGSM_STANDARD_GAS_VOLUME = *Math::GSL::Constc::GSL_CONST_CGSM_STANDARD_GAS_VOLUME;
*GSL_CONST_CGSM_MINUTE = *Math::GSL::Constc::GSL_CONST_CGSM_MINUTE;
*GSL_CONST_CGSM_HOUR = *Math::GSL::Constc::GSL_CONST_CGSM_HOUR;
*GSL_CONST_CGSM_DAY = *Math::GSL::Constc::GSL_CONST_CGSM_DAY;
*GSL_CONST_CGSM_WEEK = *Math::GSL::Constc::GSL_CONST_CGSM_WEEK;
*GSL_CONST_CGSM_INCH = *Math::GSL::Constc::GSL_CONST_CGSM_INCH;
*GSL_CONST_CGSM_FOOT = *Math::GSL::Constc::GSL_CONST_CGSM_FOOT;
*GSL_CONST_CGSM_YARD = *Math::GSL::Constc::GSL_CONST_CGSM_YARD;
*GSL_CONST_CGSM_MILE = *Math::GSL::Constc::GSL_CONST_CGSM_MILE;
*GSL_CONST_CGSM_NAUTICAL_MILE = *Math::GSL::Constc::GSL_CONST_CGSM_NAUTICAL_MILE;
*GSL_CONST_CGSM_FATHOM = *Math::GSL::Constc::GSL_CONST_CGSM_FATHOM;
*GSL_CONST_CGSM_MIL = *Math::GSL::Constc::GSL_CONST_CGSM_MIL;
*GSL_CONST_CGSM_POINT = *Math::GSL::Constc::GSL_CONST_CGSM_POINT;
*GSL_CONST_CGSM_TEXPOINT = *Math::GSL::Constc::GSL_CONST_CGSM_TEXPOINT;
*GSL_CONST_CGSM_MICRON = *Math::GSL::Constc::GSL_CONST_CGSM_MICRON;
*GSL_CONST_CGSM_ANGSTROM = *Math::GSL::Constc::GSL_CONST_CGSM_ANGSTROM;
*GSL_CONST_CGSM_HECTARE = *Math::GSL::Constc::GSL_CONST_CGSM_HECTARE;
*GSL_CONST_CGSM_ACRE = *Math::GSL::Constc::GSL_CONST_CGSM_ACRE;
*GSL_CONST_CGSM_BARN = *Math::GSL::Constc::GSL_CONST_CGSM_BARN;
*GSL_CONST_CGSM_LITER = *Math::GSL::Constc::GSL_CONST_CGSM_LITER;
*GSL_CONST_CGSM_US_GALLON = *Math::GSL::Constc::GSL_CONST_CGSM_US_GALLON;
*GSL_CONST_CGSM_QUART = *Math::GSL::Constc::GSL_CONST_CGSM_QUART;
*GSL_CONST_CGSM_PINT = *Math::GSL::Constc::GSL_CONST_CGSM_PINT;
*GSL_CONST_CGSM_CUP = *Math::GSL::Constc::GSL_CONST_CGSM_CUP;
*GSL_CONST_CGSM_FLUID_OUNCE = *Math::GSL::Constc::GSL_CONST_CGSM_FLUID_OUNCE;
*GSL_CONST_CGSM_TABLESPOON = *Math::GSL::Constc::GSL_CONST_CGSM_TABLESPOON;
*GSL_CONST_CGSM_TEASPOON = *Math::GSL::Constc::GSL_CONST_CGSM_TEASPOON;
*GSL_CONST_CGSM_CANADIAN_GALLON = *Math::GSL::Constc::GSL_CONST_CGSM_CANADIAN_GALLON;
*GSL_CONST_CGSM_UK_GALLON = *Math::GSL::Constc::GSL_CONST_CGSM_UK_GALLON;
*GSL_CONST_CGSM_MILES_PER_HOUR = *Math::GSL::Constc::GSL_CONST_CGSM_MILES_PER_HOUR;
*GSL_CONST_CGSM_KILOMETERS_PER_HOUR = *Math::GSL::Constc::GSL_CONST_CGSM_KILOMETERS_PER_HOUR;
*GSL_CONST_CGSM_KNOT = *Math::GSL::Constc::GSL_CONST_CGSM_KNOT;
*GSL_CONST_CGSM_POUND_MASS = *Math::GSL::Constc::GSL_CONST_CGSM_POUND_MASS;
*GSL_CONST_CGSM_OUNCE_MASS = *Math::GSL::Constc::GSL_CONST_CGSM_OUNCE_MASS;
*GSL_CONST_CGSM_TON = *Math::GSL::Constc::GSL_CONST_CGSM_TON;
*GSL_CONST_CGSM_METRIC_TON = *Math::GSL::Constc::GSL_CONST_CGSM_METRIC_TON;
*GSL_CONST_CGSM_UK_TON = *Math::GSL::Constc::GSL_CONST_CGSM_UK_TON;
*GSL_CONST_CGSM_TROY_OUNCE = *Math::GSL::Constc::GSL_CONST_CGSM_TROY_OUNCE;
*GSL_CONST_CGSM_CARAT = *Math::GSL::Constc::GSL_CONST_CGSM_CARAT;
*GSL_CONST_CGSM_UNIFIED_ATOMIC_MASS = *Math::GSL::Constc::GSL_CONST_CGSM_UNIFIED_ATOMIC_MASS;
*GSL_CONST_CGSM_GRAM_FORCE = *Math::GSL::Constc::GSL_CONST_CGSM_GRAM_FORCE;
*GSL_CONST_CGSM_POUND_FORCE = *Math::GSL::Constc::GSL_CONST_CGSM_POUND_FORCE;
*GSL_CONST_CGSM_KILOPOUND_FORCE = *Math::GSL::Constc::GSL_CONST_CGSM_KILOPOUND_FORCE;
*GSL_CONST_CGSM_POUNDAL = *Math::GSL::Constc::GSL_CONST_CGSM_POUNDAL;
*GSL_CONST_CGSM_CALORIE = *Math::GSL::Constc::GSL_CONST_CGSM_CALORIE;
*GSL_CONST_CGSM_BTU = *Math::GSL::Constc::GSL_CONST_CGSM_BTU;
*GSL_CONST_CGSM_THERM = *Math::GSL::Constc::GSL_CONST_CGSM_THERM;
*GSL_CONST_CGSM_HORSEPOWER = *Math::GSL::Constc::GSL_CONST_CGSM_HORSEPOWER;
*GSL_CONST_CGSM_BAR = *Math::GSL::Constc::GSL_CONST_CGSM_BAR;
*GSL_CONST_CGSM_STD_ATMOSPHERE = *Math::GSL::Constc::GSL_CONST_CGSM_STD_ATMOSPHERE;
*GSL_CONST_CGSM_TORR = *Math::GSL::Constc::GSL_CONST_CGSM_TORR;
*GSL_CONST_CGSM_METER_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_CGSM_METER_OF_MERCURY;
*GSL_CONST_CGSM_INCH_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_CGSM_INCH_OF_MERCURY;
*GSL_CONST_CGSM_INCH_OF_WATER = *Math::GSL::Constc::GSL_CONST_CGSM_INCH_OF_WATER;
*GSL_CONST_CGSM_PSI = *Math::GSL::Constc::GSL_CONST_CGSM_PSI;
*GSL_CONST_CGSM_POISE = *Math::GSL::Constc::GSL_CONST_CGSM_POISE;
*GSL_CONST_CGSM_STOKES = *Math::GSL::Constc::GSL_CONST_CGSM_STOKES;
*GSL_CONST_CGSM_FARADAY = *Math::GSL::Constc::GSL_CONST_CGSM_FARADAY;
*GSL_CONST_CGSM_ELECTRON_CHARGE = *Math::GSL::Constc::GSL_CONST_CGSM_ELECTRON_CHARGE;
*GSL_CONST_CGSM_GAUSS = *Math::GSL::Constc::GSL_CONST_CGSM_GAUSS;
*GSL_CONST_CGSM_STILB = *Math::GSL::Constc::GSL_CONST_CGSM_STILB;
*GSL_CONST_CGSM_LUMEN = *Math::GSL::Constc::GSL_CONST_CGSM_LUMEN;
*GSL_CONST_CGSM_LUX = *Math::GSL::Constc::GSL_CONST_CGSM_LUX;
*GSL_CONST_CGSM_PHOT = *Math::GSL::Constc::GSL_CONST_CGSM_PHOT;
*GSL_CONST_CGSM_FOOTCANDLE = *Math::GSL::Constc::GSL_CONST_CGSM_FOOTCANDLE;
*GSL_CONST_CGSM_LAMBERT = *Math::GSL::Constc::GSL_CONST_CGSM_LAMBERT;
*GSL_CONST_CGSM_FOOTLAMBERT = *Math::GSL::Constc::GSL_CONST_CGSM_FOOTLAMBERT;
*GSL_CONST_CGSM_CURIE = *Math::GSL::Constc::GSL_CONST_CGSM_CURIE;
*GSL_CONST_CGSM_ROENTGEN = *Math::GSL::Constc::GSL_CONST_CGSM_ROENTGEN;
*GSL_CONST_CGSM_RAD = *Math::GSL::Constc::GSL_CONST_CGSM_RAD;
*GSL_CONST_CGSM_SOLAR_MASS = *Math::GSL::Constc::GSL_CONST_CGSM_SOLAR_MASS;
*GSL_CONST_CGSM_BOHR_RADIUS = *Math::GSL::Constc::GSL_CONST_CGSM_BOHR_RADIUS;
*GSL_CONST_CGSM_NEWTON = *Math::GSL::Constc::GSL_CONST_CGSM_NEWTON;
*GSL_CONST_CGSM_DYNE = *Math::GSL::Constc::GSL_CONST_CGSM_DYNE;
*GSL_CONST_CGSM_JOULE = *Math::GSL::Constc::GSL_CONST_CGSM_JOULE;
*GSL_CONST_CGSM_ERG = *Math::GSL::Constc::GSL_CONST_CGSM_ERG;
*GSL_CONST_CGSM_STEFAN_BOLTZMANN_CONSTANT = *Math::GSL::Constc::GSL_CONST_CGSM_STEFAN_BOLTZMANN_CONSTANT;
*GSL_CONST_CGSM_THOMSON_CROSS_SECTION = *Math::GSL::Constc::GSL_CONST_CGSM_THOMSON_CROSS_SECTION;
*GSL_CONST_MKS_SPEED_OF_LIGHT = *Math::GSL::Constc::GSL_CONST_MKS_SPEED_OF_LIGHT;
*GSL_CONST_MKS_GRAVITATIONAL_CONSTANT = *Math::GSL::Constc::GSL_CONST_MKS_GRAVITATIONAL_CONSTANT;
*GSL_CONST_MKS_PLANCKS_CONSTANT_H = *Math::GSL::Constc::GSL_CONST_MKS_PLANCKS_CONSTANT_H;
*GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR = *Math::GSL::Constc::GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR;
*GSL_CONST_MKS_ASTRONOMICAL_UNIT = *Math::GSL::Constc::GSL_CONST_MKS_ASTRONOMICAL_UNIT;
*GSL_CONST_MKS_LIGHT_YEAR = *Math::GSL::Constc::GSL_CONST_MKS_LIGHT_YEAR;
*GSL_CONST_MKS_PARSEC = *Math::GSL::Constc::GSL_CONST_MKS_PARSEC;
*GSL_CONST_MKS_GRAV_ACCEL = *Math::GSL::Constc::GSL_CONST_MKS_GRAV_ACCEL;
*GSL_CONST_MKS_ELECTRON_VOLT = *Math::GSL::Constc::GSL_CONST_MKS_ELECTRON_VOLT;
*GSL_CONST_MKS_MASS_ELECTRON = *Math::GSL::Constc::GSL_CONST_MKS_MASS_ELECTRON;
*GSL_CONST_MKS_MASS_MUON = *Math::GSL::Constc::GSL_CONST_MKS_MASS_MUON;
*GSL_CONST_MKS_MASS_PROTON = *Math::GSL::Constc::GSL_CONST_MKS_MASS_PROTON;
*GSL_CONST_MKS_MASS_NEUTRON = *Math::GSL::Constc::GSL_CONST_MKS_MASS_NEUTRON;
*GSL_CONST_MKS_RYDBERG = *Math::GSL::Constc::GSL_CONST_MKS_RYDBERG;
*GSL_CONST_MKS_BOLTZMANN = *Math::GSL::Constc::GSL_CONST_MKS_BOLTZMANN;
*GSL_CONST_MKS_BOHR_MAGNETON = *Math::GSL::Constc::GSL_CONST_MKS_BOHR_MAGNETON;
*GSL_CONST_MKS_NUCLEAR_MAGNETON = *Math::GSL::Constc::GSL_CONST_MKS_NUCLEAR_MAGNETON;
*GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT;
*GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT;
*GSL_CONST_MKS_MOLAR_GAS = *Math::GSL::Constc::GSL_CONST_MKS_MOLAR_GAS;
*GSL_CONST_MKS_STANDARD_GAS_VOLUME = *Math::GSL::Constc::GSL_CONST_MKS_STANDARD_GAS_VOLUME;
*GSL_CONST_MKS_MINUTE = *Math::GSL::Constc::GSL_CONST_MKS_MINUTE;
*GSL_CONST_MKS_HOUR = *Math::GSL::Constc::GSL_CONST_MKS_HOUR;
*GSL_CONST_MKS_DAY = *Math::GSL::Constc::GSL_CONST_MKS_DAY;
*GSL_CONST_MKS_WEEK = *Math::GSL::Constc::GSL_CONST_MKS_WEEK;
*GSL_CONST_MKS_INCH = *Math::GSL::Constc::GSL_CONST_MKS_INCH;
*GSL_CONST_MKS_FOOT = *Math::GSL::Constc::GSL_CONST_MKS_FOOT;
*GSL_CONST_MKS_YARD = *Math::GSL::Constc::GSL_CONST_MKS_YARD;
*GSL_CONST_MKS_MILE = *Math::GSL::Constc::GSL_CONST_MKS_MILE;
*GSL_CONST_MKS_NAUTICAL_MILE = *Math::GSL::Constc::GSL_CONST_MKS_NAUTICAL_MILE;
*GSL_CONST_MKS_FATHOM = *Math::GSL::Constc::GSL_CONST_MKS_FATHOM;
*GSL_CONST_MKS_MIL = *Math::GSL::Constc::GSL_CONST_MKS_MIL;
*GSL_CONST_MKS_POINT = *Math::GSL::Constc::GSL_CONST_MKS_POINT;
*GSL_CONST_MKS_TEXPOINT = *Math::GSL::Constc::GSL_CONST_MKS_TEXPOINT;
*GSL_CONST_MKS_MICRON = *Math::GSL::Constc::GSL_CONST_MKS_MICRON;
*GSL_CONST_MKS_ANGSTROM = *Math::GSL::Constc::GSL_CONST_MKS_ANGSTROM;
*GSL_CONST_MKS_HECTARE = *Math::GSL::Constc::GSL_CONST_MKS_HECTARE;
*GSL_CONST_MKS_ACRE = *Math::GSL::Constc::GSL_CONST_MKS_ACRE;
*GSL_CONST_MKS_BARN = *Math::GSL::Constc::GSL_CONST_MKS_BARN;
*GSL_CONST_MKS_LITER = *Math::GSL::Constc::GSL_CONST_MKS_LITER;
*GSL_CONST_MKS_US_GALLON = *Math::GSL::Constc::GSL_CONST_MKS_US_GALLON;
*GSL_CONST_MKS_QUART = *Math::GSL::Constc::GSL_CONST_MKS_QUART;
*GSL_CONST_MKS_PINT = *Math::GSL::Constc::GSL_CONST_MKS_PINT;
*GSL_CONST_MKS_CUP = *Math::GSL::Constc::GSL_CONST_MKS_CUP;
*GSL_CONST_MKS_FLUID_OUNCE = *Math::GSL::Constc::GSL_CONST_MKS_FLUID_OUNCE;
*GSL_CONST_MKS_TABLESPOON = *Math::GSL::Constc::GSL_CONST_MKS_TABLESPOON;
*GSL_CONST_MKS_TEASPOON = *Math::GSL::Constc::GSL_CONST_MKS_TEASPOON;
*GSL_CONST_MKS_CANADIAN_GALLON = *Math::GSL::Constc::GSL_CONST_MKS_CANADIAN_GALLON;
*GSL_CONST_MKS_UK_GALLON = *Math::GSL::Constc::GSL_CONST_MKS_UK_GALLON;
*GSL_CONST_MKS_MILES_PER_HOUR = *Math::GSL::Constc::GSL_CONST_MKS_MILES_PER_HOUR;
*GSL_CONST_MKS_KILOMETERS_PER_HOUR = *Math::GSL::Constc::GSL_CONST_MKS_KILOMETERS_PER_HOUR;
*GSL_CONST_MKS_KNOT = *Math::GSL::Constc::GSL_CONST_MKS_KNOT;
*GSL_CONST_MKS_POUND_MASS = *Math::GSL::Constc::GSL_CONST_MKS_POUND_MASS;
*GSL_CONST_MKS_OUNCE_MASS = *Math::GSL::Constc::GSL_CONST_MKS_OUNCE_MASS;
*GSL_CONST_MKS_TON = *Math::GSL::Constc::GSL_CONST_MKS_TON;
*GSL_CONST_MKS_METRIC_TON = *Math::GSL::Constc::GSL_CONST_MKS_METRIC_TON;
*GSL_CONST_MKS_UK_TON = *Math::GSL::Constc::GSL_CONST_MKS_UK_TON;
*GSL_CONST_MKS_TROY_OUNCE = *Math::GSL::Constc::GSL_CONST_MKS_TROY_OUNCE;
*GSL_CONST_MKS_CARAT = *Math::GSL::Constc::GSL_CONST_MKS_CARAT;
*GSL_CONST_MKS_UNIFIED_ATOMIC_MASS = *Math::GSL::Constc::GSL_CONST_MKS_UNIFIED_ATOMIC_MASS;
*GSL_CONST_MKS_GRAM_FORCE = *Math::GSL::Constc::GSL_CONST_MKS_GRAM_FORCE;
*GSL_CONST_MKS_POUND_FORCE = *Math::GSL::Constc::GSL_CONST_MKS_POUND_FORCE;
*GSL_CONST_MKS_KILOPOUND_FORCE = *Math::GSL::Constc::GSL_CONST_MKS_KILOPOUND_FORCE;
*GSL_CONST_MKS_POUNDAL = *Math::GSL::Constc::GSL_CONST_MKS_POUNDAL;
*GSL_CONST_MKS_CALORIE = *Math::GSL::Constc::GSL_CONST_MKS_CALORIE;
*GSL_CONST_MKS_BTU = *Math::GSL::Constc::GSL_CONST_MKS_BTU;
*GSL_CONST_MKS_THERM = *Math::GSL::Constc::GSL_CONST_MKS_THERM;
*GSL_CONST_MKS_HORSEPOWER = *Math::GSL::Constc::GSL_CONST_MKS_HORSEPOWER;
*GSL_CONST_MKS_BAR = *Math::GSL::Constc::GSL_CONST_MKS_BAR;
*GSL_CONST_MKS_STD_ATMOSPHERE = *Math::GSL::Constc::GSL_CONST_MKS_STD_ATMOSPHERE;
*GSL_CONST_MKS_TORR = *Math::GSL::Constc::GSL_CONST_MKS_TORR;
*GSL_CONST_MKS_METER_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_MKS_METER_OF_MERCURY;
*GSL_CONST_MKS_INCH_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_MKS_INCH_OF_MERCURY;
*GSL_CONST_MKS_INCH_OF_WATER = *Math::GSL::Constc::GSL_CONST_MKS_INCH_OF_WATER;
*GSL_CONST_MKS_PSI = *Math::GSL::Constc::GSL_CONST_MKS_PSI;
*GSL_CONST_MKS_POISE = *Math::GSL::Constc::GSL_CONST_MKS_POISE;
*GSL_CONST_MKS_STOKES = *Math::GSL::Constc::GSL_CONST_MKS_STOKES;
*GSL_CONST_MKS_FARADAY = *Math::GSL::Constc::GSL_CONST_MKS_FARADAY;
*GSL_CONST_MKS_ELECTRON_CHARGE = *Math::GSL::Constc::GSL_CONST_MKS_ELECTRON_CHARGE;
*GSL_CONST_MKS_GAUSS = *Math::GSL::Constc::GSL_CONST_MKS_GAUSS;
*GSL_CONST_MKS_STILB = *Math::GSL::Constc::GSL_CONST_MKS_STILB;
*GSL_CONST_MKS_LUMEN = *Math::GSL::Constc::GSL_CONST_MKS_LUMEN;
*GSL_CONST_MKS_LUX = *Math::GSL::Constc::GSL_CONST_MKS_LUX;
*GSL_CONST_MKS_PHOT = *Math::GSL::Constc::GSL_CONST_MKS_PHOT;
*GSL_CONST_MKS_FOOTCANDLE = *Math::GSL::Constc::GSL_CONST_MKS_FOOTCANDLE;
*GSL_CONST_MKS_LAMBERT = *Math::GSL::Constc::GSL_CONST_MKS_LAMBERT;
*GSL_CONST_MKS_FOOTLAMBERT = *Math::GSL::Constc::GSL_CONST_MKS_FOOTLAMBERT;
*GSL_CONST_MKS_CURIE = *Math::GSL::Constc::GSL_CONST_MKS_CURIE;
*GSL_CONST_MKS_ROENTGEN = *Math::GSL::Constc::GSL_CONST_MKS_ROENTGEN;
*GSL_CONST_MKS_RAD = *Math::GSL::Constc::GSL_CONST_MKS_RAD;
*GSL_CONST_MKS_SOLAR_MASS = *Math::GSL::Constc::GSL_CONST_MKS_SOLAR_MASS;
*GSL_CONST_MKS_BOHR_RADIUS = *Math::GSL::Constc::GSL_CONST_MKS_BOHR_RADIUS;
*GSL_CONST_MKS_NEWTON = *Math::GSL::Constc::GSL_CONST_MKS_NEWTON;
*GSL_CONST_MKS_DYNE = *Math::GSL::Constc::GSL_CONST_MKS_DYNE;
*GSL_CONST_MKS_JOULE = *Math::GSL::Constc::GSL_CONST_MKS_JOULE;
*GSL_CONST_MKS_ERG = *Math::GSL::Constc::GSL_CONST_MKS_ERG;
*GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT = *Math::GSL::Constc::GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT;
*GSL_CONST_MKS_THOMSON_CROSS_SECTION = *Math::GSL::Constc::GSL_CONST_MKS_THOMSON_CROSS_SECTION;
*GSL_CONST_MKS_VACUUM_PERMITTIVITY = *Math::GSL::Constc::GSL_CONST_MKS_VACUUM_PERMITTIVITY;
*GSL_CONST_MKS_VACUUM_PERMEABILITY = *Math::GSL::Constc::GSL_CONST_MKS_VACUUM_PERMEABILITY;
*GSL_CONST_MKS_DEBYE = *Math::GSL::Constc::GSL_CONST_MKS_DEBYE;
*GSL_CONST_MKSA_SPEED_OF_LIGHT = *Math::GSL::Constc::GSL_CONST_MKSA_SPEED_OF_LIGHT;
*GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT = *Math::GSL::Constc::GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT;
*GSL_CONST_MKSA_PLANCKS_CONSTANT_H = *Math::GSL::Constc::GSL_CONST_MKSA_PLANCKS_CONSTANT_H;
*GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR = *Math::GSL::Constc::GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR;
*GSL_CONST_MKSA_ASTRONOMICAL_UNIT = *Math::GSL::Constc::GSL_CONST_MKSA_ASTRONOMICAL_UNIT;
*GSL_CONST_MKSA_LIGHT_YEAR = *Math::GSL::Constc::GSL_CONST_MKSA_LIGHT_YEAR;
*GSL_CONST_MKSA_PARSEC = *Math::GSL::Constc::GSL_CONST_MKSA_PARSEC;
*GSL_CONST_MKSA_GRAV_ACCEL = *Math::GSL::Constc::GSL_CONST_MKSA_GRAV_ACCEL;
*GSL_CONST_MKSA_ELECTRON_VOLT = *Math::GSL::Constc::GSL_CONST_MKSA_ELECTRON_VOLT;
*GSL_CONST_MKSA_MASS_ELECTRON = *Math::GSL::Constc::GSL_CONST_MKSA_MASS_ELECTRON;
*GSL_CONST_MKSA_MASS_MUON = *Math::GSL::Constc::GSL_CONST_MKSA_MASS_MUON;
*GSL_CONST_MKSA_MASS_PROTON = *Math::GSL::Constc::GSL_CONST_MKSA_MASS_PROTON;
*GSL_CONST_MKSA_MASS_NEUTRON = *Math::GSL::Constc::GSL_CONST_MKSA_MASS_NEUTRON;
*GSL_CONST_MKSA_RYDBERG = *Math::GSL::Constc::GSL_CONST_MKSA_RYDBERG;
*GSL_CONST_MKSA_BOLTZMANN = *Math::GSL::Constc::GSL_CONST_MKSA_BOLTZMANN;
*GSL_CONST_MKSA_BOHR_MAGNETON = *Math::GSL::Constc::GSL_CONST_MKSA_BOHR_MAGNETON;
*GSL_CONST_MKSA_NUCLEAR_MAGNETON = *Math::GSL::Constc::GSL_CONST_MKSA_NUCLEAR_MAGNETON;
*GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT;
*GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT = *Math::GSL::Constc::GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT;
*GSL_CONST_MKSA_MOLAR_GAS = *Math::GSL::Constc::GSL_CONST_MKSA_MOLAR_GAS;
*GSL_CONST_MKSA_STANDARD_GAS_VOLUME = *Math::GSL::Constc::GSL_CONST_MKSA_STANDARD_GAS_VOLUME;
*GSL_CONST_MKSA_MINUTE = *Math::GSL::Constc::GSL_CONST_MKSA_MINUTE;
*GSL_CONST_MKSA_HOUR = *Math::GSL::Constc::GSL_CONST_MKSA_HOUR;
*GSL_CONST_MKSA_DAY = *Math::GSL::Constc::GSL_CONST_MKSA_DAY;
*GSL_CONST_MKSA_WEEK = *Math::GSL::Constc::GSL_CONST_MKSA_WEEK;
*GSL_CONST_MKSA_INCH = *Math::GSL::Constc::GSL_CONST_MKSA_INCH;
*GSL_CONST_MKSA_FOOT = *Math::GSL::Constc::GSL_CONST_MKSA_FOOT;
*GSL_CONST_MKSA_YARD = *Math::GSL::Constc::GSL_CONST_MKSA_YARD;
*GSL_CONST_MKSA_MILE = *Math::GSL::Constc::GSL_CONST_MKSA_MILE;
*GSL_CONST_MKSA_NAUTICAL_MILE = *Math::GSL::Constc::GSL_CONST_MKSA_NAUTICAL_MILE;
*GSL_CONST_MKSA_FATHOM = *Math::GSL::Constc::GSL_CONST_MKSA_FATHOM;
*GSL_CONST_MKSA_MIL = *Math::GSL::Constc::GSL_CONST_MKSA_MIL;
*GSL_CONST_MKSA_POINT = *Math::GSL::Constc::GSL_CONST_MKSA_POINT;
*GSL_CONST_MKSA_TEXPOINT = *Math::GSL::Constc::GSL_CONST_MKSA_TEXPOINT;
*GSL_CONST_MKSA_MICRON = *Math::GSL::Constc::GSL_CONST_MKSA_MICRON;
*GSL_CONST_MKSA_ANGSTROM = *Math::GSL::Constc::GSL_CONST_MKSA_ANGSTROM;
*GSL_CONST_MKSA_HECTARE = *Math::GSL::Constc::GSL_CONST_MKSA_HECTARE;
*GSL_CONST_MKSA_ACRE = *Math::GSL::Constc::GSL_CONST_MKSA_ACRE;
*GSL_CONST_MKSA_BARN = *Math::GSL::Constc::GSL_CONST_MKSA_BARN;
*GSL_CONST_MKSA_LITER = *Math::GSL::Constc::GSL_CONST_MKSA_LITER;
*GSL_CONST_MKSA_US_GALLON = *Math::GSL::Constc::GSL_CONST_MKSA_US_GALLON;
*GSL_CONST_MKSA_QUART = *Math::GSL::Constc::GSL_CONST_MKSA_QUART;
*GSL_CONST_MKSA_PINT = *Math::GSL::Constc::GSL_CONST_MKSA_PINT;
*GSL_CONST_MKSA_CUP = *Math::GSL::Constc::GSL_CONST_MKSA_CUP;
*GSL_CONST_MKSA_FLUID_OUNCE = *Math::GSL::Constc::GSL_CONST_MKSA_FLUID_OUNCE;
*GSL_CONST_MKSA_TABLESPOON = *Math::GSL::Constc::GSL_CONST_MKSA_TABLESPOON;
*GSL_CONST_MKSA_TEASPOON = *Math::GSL::Constc::GSL_CONST_MKSA_TEASPOON;
*GSL_CONST_MKSA_CANADIAN_GALLON = *Math::GSL::Constc::GSL_CONST_MKSA_CANADIAN_GALLON;
*GSL_CONST_MKSA_UK_GALLON = *Math::GSL::Constc::GSL_CONST_MKSA_UK_GALLON;
*GSL_CONST_MKSA_MILES_PER_HOUR = *Math::GSL::Constc::GSL_CONST_MKSA_MILES_PER_HOUR;
*GSL_CONST_MKSA_KILOMETERS_PER_HOUR = *Math::GSL::Constc::GSL_CONST_MKSA_KILOMETERS_PER_HOUR;
*GSL_CONST_MKSA_KNOT = *Math::GSL::Constc::GSL_CONST_MKSA_KNOT;
*GSL_CONST_MKSA_POUND_MASS = *Math::GSL::Constc::GSL_CONST_MKSA_POUND_MASS;
*GSL_CONST_MKSA_OUNCE_MASS = *Math::GSL::Constc::GSL_CONST_MKSA_OUNCE_MASS;
*GSL_CONST_MKSA_TON = *Math::GSL::Constc::GSL_CONST_MKSA_TON;
*GSL_CONST_MKSA_METRIC_TON = *Math::GSL::Constc::GSL_CONST_MKSA_METRIC_TON;
*GSL_CONST_MKSA_UK_TON = *Math::GSL::Constc::GSL_CONST_MKSA_UK_TON;
*GSL_CONST_MKSA_TROY_OUNCE = *Math::GSL::Constc::GSL_CONST_MKSA_TROY_OUNCE;
*GSL_CONST_MKSA_CARAT = *Math::GSL::Constc::GSL_CONST_MKSA_CARAT;
*GSL_CONST_MKSA_UNIFIED_ATOMIC_MASS = *Math::GSL::Constc::GSL_CONST_MKSA_UNIFIED_ATOMIC_MASS;
*GSL_CONST_MKSA_GRAM_FORCE = *Math::GSL::Constc::GSL_CONST_MKSA_GRAM_FORCE;
*GSL_CONST_MKSA_POUND_FORCE = *Math::GSL::Constc::GSL_CONST_MKSA_POUND_FORCE;
*GSL_CONST_MKSA_KILOPOUND_FORCE = *Math::GSL::Constc::GSL_CONST_MKSA_KILOPOUND_FORCE;
*GSL_CONST_MKSA_POUNDAL = *Math::GSL::Constc::GSL_CONST_MKSA_POUNDAL;
*GSL_CONST_MKSA_CALORIE = *Math::GSL::Constc::GSL_CONST_MKSA_CALORIE;
*GSL_CONST_MKSA_BTU = *Math::GSL::Constc::GSL_CONST_MKSA_BTU;
*GSL_CONST_MKSA_THERM = *Math::GSL::Constc::GSL_CONST_MKSA_THERM;
*GSL_CONST_MKSA_HORSEPOWER = *Math::GSL::Constc::GSL_CONST_MKSA_HORSEPOWER;
*GSL_CONST_MKSA_BAR = *Math::GSL::Constc::GSL_CONST_MKSA_BAR;
*GSL_CONST_MKSA_STD_ATMOSPHERE = *Math::GSL::Constc::GSL_CONST_MKSA_STD_ATMOSPHERE;
*GSL_CONST_MKSA_TORR = *Math::GSL::Constc::GSL_CONST_MKSA_TORR;
*GSL_CONST_MKSA_METER_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_MKSA_METER_OF_MERCURY;
*GSL_CONST_MKSA_INCH_OF_MERCURY = *Math::GSL::Constc::GSL_CONST_MKSA_INCH_OF_MERCURY;
*GSL_CONST_MKSA_INCH_OF_WATER = *Math::GSL::Constc::GSL_CONST_MKSA_INCH_OF_WATER;
*GSL_CONST_MKSA_PSI = *Math::GSL::Constc::GSL_CONST_MKSA_PSI;
*GSL_CONST_MKSA_POISE = *Math::GSL::Constc::GSL_CONST_MKSA_POISE;
*GSL_CONST_MKSA_STOKES = *Math::GSL::Constc::GSL_CONST_MKSA_STOKES;
*GSL_CONST_MKSA_FARADAY = *Math::GSL::Constc::GSL_CONST_MKSA_FARADAY;
*GSL_CONST_MKSA_ELECTRON_CHARGE = *Math::GSL::Constc::GSL_CONST_MKSA_ELECTRON_CHARGE;
*GSL_CONST_MKSA_GAUSS = *Math::GSL::Constc::GSL_CONST_MKSA_GAUSS;
*GSL_CONST_MKSA_STILB = *Math::GSL::Constc::GSL_CONST_MKSA_STILB;
*GSL_CONST_MKSA_LUMEN = *Math::GSL::Constc::GSL_CONST_MKSA_LUMEN;
*GSL_CONST_MKSA_LUX = *Math::GSL::Constc::GSL_CONST_MKSA_LUX;
*GSL_CONST_MKSA_PHOT = *Math::GSL::Constc::GSL_CONST_MKSA_PHOT;
*GSL_CONST_MKSA_FOOTCANDLE = *Math::GSL::Constc::GSL_CONST_MKSA_FOOTCANDLE;
*GSL_CONST_MKSA_LAMBERT = *Math::GSL::Constc::GSL_CONST_MKSA_LAMBERT;
*GSL_CONST_MKSA_FOOTLAMBERT = *Math::GSL::Constc::GSL_CONST_MKSA_FOOTLAMBERT;
*GSL_CONST_MKSA_CURIE = *Math::GSL::Constc::GSL_CONST_MKSA_CURIE;
*GSL_CONST_MKSA_ROENTGEN = *Math::GSL::Constc::GSL_CONST_MKSA_ROENTGEN;
*GSL_CONST_MKSA_RAD = *Math::GSL::Constc::GSL_CONST_MKSA_RAD;
*GSL_CONST_MKSA_SOLAR_MASS = *Math::GSL::Constc::GSL_CONST_MKSA_SOLAR_MASS;
*GSL_CONST_MKSA_BOHR_RADIUS = *Math::GSL::Constc::GSL_CONST_MKSA_BOHR_RADIUS;
*GSL_CONST_MKSA_NEWTON = *Math::GSL::Constc::GSL_CONST_MKSA_NEWTON;
*GSL_CONST_MKSA_DYNE = *Math::GSL::Constc::GSL_CONST_MKSA_DYNE;
*GSL_CONST_MKSA_JOULE = *Math::GSL::Constc::GSL_CONST_MKSA_JOULE;
*GSL_CONST_MKSA_ERG = *Math::GSL::Constc::GSL_CONST_MKSA_ERG;
*GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT = *Math::GSL::Constc::GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT;
*GSL_CONST_MKSA_THOMSON_CROSS_SECTION = *Math::GSL::Constc::GSL_CONST_MKSA_THOMSON_CROSS_SECTION;
*GSL_CONST_MKSA_VACUUM_PERMITTIVITY = *Math::GSL::Constc::GSL_CONST_MKSA_VACUUM_PERMITTIVITY;
*GSL_CONST_MKSA_VACUUM_PERMEABILITY = *Math::GSL::Constc::GSL_CONST_MKSA_VACUUM_PERMEABILITY;
*GSL_CONST_MKSA_DEBYE = *Math::GSL::Constc::GSL_CONST_MKSA_DEBYE;
*GSL_CONST_NUM_FINE_STRUCTURE = *Math::GSL::Constc::GSL_CONST_NUM_FINE_STRUCTURE;
*GSL_CONST_NUM_AVOGADRO = *Math::GSL::Constc::GSL_CONST_NUM_AVOGADRO;
*GSL_CONST_NUM_YOTTA = *Math::GSL::Constc::GSL_CONST_NUM_YOTTA;
*GSL_CONST_NUM_ZETTA = *Math::GSL::Constc::GSL_CONST_NUM_ZETTA;
*GSL_CONST_NUM_EXA = *Math::GSL::Constc::GSL_CONST_NUM_EXA;
*GSL_CONST_NUM_PETA = *Math::GSL::Constc::GSL_CONST_NUM_PETA;
*GSL_CONST_NUM_TERA = *Math::GSL::Constc::GSL_CONST_NUM_TERA;
*GSL_CONST_NUM_GIGA = *Math::GSL::Constc::GSL_CONST_NUM_GIGA;
*GSL_CONST_NUM_MEGA = *Math::GSL::Constc::GSL_CONST_NUM_MEGA;
*GSL_CONST_NUM_KILO = *Math::GSL::Constc::GSL_CONST_NUM_KILO;
*GSL_CONST_NUM_MILLI = *Math::GSL::Constc::GSL_CONST_NUM_MILLI;
*GSL_CONST_NUM_MICRO = *Math::GSL::Constc::GSL_CONST_NUM_MICRO;
*GSL_CONST_NUM_NANO = *Math::GSL::Constc::GSL_CONST_NUM_NANO;
*GSL_CONST_NUM_PICO = *Math::GSL::Constc::GSL_CONST_NUM_PICO;
*GSL_CONST_NUM_FEMTO = *Math::GSL::Constc::GSL_CONST_NUM_FEMTO;
*GSL_CONST_NUM_ATTO = *Math::GSL::Constc::GSL_CONST_NUM_ATTO;
*GSL_CONST_NUM_ZEPTO = *Math::GSL::Constc::GSL_CONST_NUM_ZEPTO;
*GSL_CONST_NUM_YOCTO = *Math::GSL::Constc::GSL_CONST_NUM_YOCTO;

@EXPORT_math = qw/
               $M_E 
               $M_LOG2E 
               $M_LOG10E 
               $M_SQRT2 
               $M_SQRT1_2 
               $M_SQRT3 
               $M_PI 
               $M_PI_2 
               $M_PI_4 
               $M_SQRTPI 
               $M_2_SQRTPI 
               $M_1_PI 
               $M_2_PI 
               $M_LN10 
               $M_LN2 
               $M_LNPI 
               $M_EULER 
              /;
@EXPORT_cgs = qw/
               $GSL_CONST_CGS_SPEED_OF_LIGHT 
               $GSL_CONST_CGS_GRAVITATIONAL_CONSTANT 
               $GSL_CONST_CGS_PLANCKS_CONSTANT_H 
               $GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR 
               $GSL_CONST_CGS_ASTRONOMICAL_UNIT 
               $GSL_CONST_CGS_LIGHT_YEAR 
               $GSL_CONST_CGS_PARSEC 
               $GSL_CONST_CGS_GRAV_ACCEL 
               $GSL_CONST_CGS_ELECTRON_VOLT 
               $GSL_CONST_CGS_MASS_ELECTRON 
               $GSL_CONST_CGS_MASS_MUON 
               $GSL_CONST_CGS_MASS_PROTON 
               $GSL_CONST_CGS_MASS_NEUTRON 
               $GSL_CONST_CGS_RYDBERG 
               $GSL_CONST_CGS_BOLTZMANN 
               $GSL_CONST_CGS_BOHR_MAGNETON 
               $GSL_CONST_CGS_NUCLEAR_MAGNETON 
               $GSL_CONST_CGS_ELECTRON_MAGNETIC_MOMENT 
               $GSL_CONST_CGS_PROTON_MAGNETIC_MOMENT 
               $GSL_CONST_CGS_MOLAR_GAS 
               $GSL_CONST_CGS_STANDARD_GAS_VOLUME 
               $GSL_CONST_CGS_MINUTE 
               $GSL_CONST_CGS_HOUR 
               $GSL_CONST_CGS_DAY 
               $GSL_CONST_CGS_WEEK 
               $GSL_CONST_CGS_INCH 
               $GSL_CONST_CGS_FOOT 
               $GSL_CONST_CGS_YARD 
               $GSL_CONST_CGS_MILE 
               $GSL_CONST_CGS_NAUTICAL_MILE 
               $GSL_CONST_CGS_FATHOM 
               $GSL_CONST_CGS_MIL 
               $GSL_CONST_CGS_POINT 
               $GSL_CONST_CGS_TEXPOINT 
               $GSL_CONST_CGS_MICRON 
               $GSL_CONST_CGS_ANGSTROM 
               $GSL_CONST_CGS_HECTARE 
               $GSL_CONST_CGS_ACRE 
               $GSL_CONST_CGS_BARN 
               $GSL_CONST_CGS_LITER 
               $GSL_CONST_CGS_US_GALLON 
               $GSL_CONST_CGS_QUART 
               $GSL_CONST_CGS_PINT 
               $GSL_CONST_CGS_CUP 
               $GSL_CONST_CGS_FLUID_OUNCE 
               $GSL_CONST_CGS_TABLESPOON 
               $GSL_CONST_CGS_TEASPOON 
               $GSL_CONST_CGS_CANADIAN_GALLON 
               $GSL_CONST_CGS_UK_GALLON 
               $GSL_CONST_CGS_MILES_PER_HOUR 
               $GSL_CONST_CGS_KILOMETERS_PER_HOUR 
               $GSL_CONST_CGS_KNOT 
               $GSL_CONST_CGS_POUND_MASS 
               $GSL_CONST_CGS_OUNCE_MASS 
               $GSL_CONST_CGS_TON 
               $GSL_CONST_CGS_METRIC_TON 
               $GSL_CONST_CGS_UK_TON 
               $GSL_CONST_CGS_TROY_OUNCE 
               $GSL_CONST_CGS_CARAT 
               $GSL_CONST_CGS_UNIFIED_ATOMIC_MASS 
               $GSL_CONST_CGS_GRAM_FORCE 
               $GSL_CONST_CGS_POUND_FORCE 
               $GSL_CONST_CGS_KILOPOUND_FORCE 
               $GSL_CONST_CGS_POUNDAL 
               $GSL_CONST_CGS_CALORIE 
               $GSL_CONST_CGS_BTU 
               $GSL_CONST_CGS_THERM 
               $GSL_CONST_CGS_HORSEPOWER 
               $GSL_CONST_CGS_BAR 
               $GSL_CONST_CGS_STD_ATMOSPHERE 
               $GSL_CONST_CGS_TORR 
               $GSL_CONST_CGS_METER_OF_MERCURY 
               $GSL_CONST_CGS_INCH_OF_MERCURY 
               $GSL_CONST_CGS_INCH_OF_WATER 
               $GSL_CONST_CGS_PSI 
               $GSL_CONST_CGS_POISE 
               $GSL_CONST_CGS_STOKES 
               $GSL_CONST_CGS_FARADAY 
               $GSL_CONST_CGS_ELECTRON_CHARGE 
               $GSL_CONST_CGS_GAUSS 
               $GSL_CONST_CGS_STILB 
               $GSL_CONST_CGS_LUMEN 
               $GSL_CONST_CGS_LUX 
               $GSL_CONST_CGS_PHOT 
               $GSL_CONST_CGS_FOOTCANDLE 
               $GSL_CONST_CGS_LAMBERT 
               $GSL_CONST_CGS_FOOTLAMBERT 
               $GSL_CONST_CGS_CURIE 
               $GSL_CONST_CGS_ROENTGEN 
               $GSL_CONST_CGS_RAD 
               $GSL_CONST_CGS_SOLAR_MASS 
               $GSL_CONST_CGS_BOHR_RADIUS 
               $GSL_CONST_CGS_NEWTON 
               $GSL_CONST_CGS_DYNE 
               $GSL_CONST_CGS_JOULE 
               $GSL_CONST_CGS_ERG 
               $GSL_CONST_CGS_STEFAN_BOLTZMANN_CONSTANT 
               $GSL_CONST_CGS_THOMSON_CROSS_SECTION 
               /;
@EXPORT_cgsm = qw/
               $GSL_CONST_CGSM_SPEED_OF_LIGHT 
               $GSL_CONST_CGSM_GRAVITATIONAL_CONSTANT 
               $GSL_CONST_CGSM_PLANCKS_CONSTANT_H 
               $GSL_CONST_CGSM_PLANCKS_CONSTANT_HBAR 
               $GSL_CONST_CGSM_ASTRONOMICAL_UNIT 
               $GSL_CONST_CGSM_LIGHT_YEAR 
               $GSL_CONST_CGSM_PARSEC 
               $GSL_CONST_CGSM_GRAV_ACCEL 
               $GSL_CONST_CGSM_ELECTRON_VOLT 
               $GSL_CONST_CGSM_MASS_ELECTRON 
               $GSL_CONST_CGSM_MASS_MUON 
               $GSL_CONST_CGSM_MASS_PROTON 
               $GSL_CONST_CGSM_MASS_NEUTRON 
               $GSL_CONST_CGSM_RYDBERG 
               $GSL_CONST_CGSM_BOLTZMANN 
               $GSL_CONST_CGSM_BOHR_MAGNETON 
               $GSL_CONST_CGSM_NUCLEAR_MAGNETON 
               $GSL_CONST_CGSM_ELECTRON_MAGNETIC_MOMENT 
               $GSL_CONST_CGSM_PROTON_MAGNETIC_MOMENT 
               $GSL_CONST_CGSM_MOLAR_GAS 
               $GSL_CONST_CGSM_STANDARD_GAS_VOLUME 
               $GSL_CONST_CGSM_MINUTE 
               $GSL_CONST_CGSM_HOUR 
               $GSL_CONST_CGSM_DAY 
               $GSL_CONST_CGSM_WEEK 
               $GSL_CONST_CGSM_INCH 
               $GSL_CONST_CGSM_FOOT 
               $GSL_CONST_CGSM_YARD 
               $GSL_CONST_CGSM_MILE 
               $GSL_CONST_CGSM_NAUTICAL_MILE 
               $GSL_CONST_CGSM_FATHOM 
               $GSL_CONST_CGSM_MIL 
               $GSL_CONST_CGSM_POINT 
               $GSL_CONST_CGSM_TEXPOINT 
               $GSL_CONST_CGSM_MICRON 
               $GSL_CONST_CGSM_ANGSTROM 
               $GSL_CONST_CGSM_HECTARE 
               $GSL_CONST_CGSM_ACRE 
               $GSL_CONST_CGSM_BARN 
               $GSL_CONST_CGSM_LITER 
               $GSL_CONST_CGSM_US_GALLON 
               $GSL_CONST_CGSM_QUART 
               $GSL_CONST_CGSM_PINT 
               $GSL_CONST_CGSM_CUP 
               $GSL_CONST_CGSM_FLUID_OUNCE 
               $GSL_CONST_CGSM_TABLESPOON 
               $GSL_CONST_CGSM_TEASPOON 
               $GSL_CONST_CGSM_CANADIAN_GALLON 
               $GSL_CONST_CGSM_UK_GALLON 
               $GSL_CONST_CGSM_MILES_PER_HOUR 
               $GSL_CONST_CGSM_KILOMETERS_PER_HOUR 
               $GSL_CONST_CGSM_KNOT 
               $GSL_CONST_CGSM_POUND_MASS 
               $GSL_CONST_CGSM_OUNCE_MASS 
               $GSL_CONST_CGSM_TON 
               $GSL_CONST_CGSM_METRIC_TON 
               $GSL_CONST_CGSM_UK_TON 
               $GSL_CONST_CGSM_TROY_OUNCE 
               $GSL_CONST_CGSM_CARAT 
               $GSL_CONST_CGSM_UNIFIED_ATOMIC_MASS 
               $GSL_CONST_CGSM_GRAM_FORCE 
               $GSL_CONST_CGSM_POUND_FORCE 
               $GSL_CONST_CGSM_KILOPOUND_FORCE 
               $GSL_CONST_CGSM_POUNDAL 
               $GSL_CONST_CGSM_CALORIE 
               $GSL_CONST_CGSM_BTU 
               $GSL_CONST_CGSM_THERM 
               $GSL_CONST_CGSM_HORSEPOWER 
               $GSL_CONST_CGSM_BAR 
               $GSL_CONST_CGSM_STD_ATMOSPHERE 
               $GSL_CONST_CGSM_TORR 
               $GSL_CONST_CGSM_METER_OF_MERCURY 
               $GSL_CONST_CGSM_INCH_OF_MERCURY 
               $GSL_CONST_CGSM_INCH_OF_WATER 
               $GSL_CONST_CGSM_PSI 
               $GSL_CONST_CGSM_POISE 
               $GSL_CONST_CGSM_STOKES 
               $GSL_CONST_CGSM_FARADAY 
               $GSL_CONST_CGSM_ELECTRON_CHARGE 
               $GSL_CONST_CGSM_GAUSS 
               $GSL_CONST_CGSM_STILB 
               $GSL_CONST_CGSM_LUMEN 
               $GSL_CONST_CGSM_LUX 
               $GSL_CONST_CGSM_PHOT 
               $GSL_CONST_CGSM_FOOTCANDLE 
               $GSL_CONST_CGSM_LAMBERT 
               $GSL_CONST_CGSM_FOOTLAMBERT 
               $GSL_CONST_CGSM_CURIE 
               $GSL_CONST_CGSM_ROENTGEN 
               $GSL_CONST_CGSM_RAD 
               $GSL_CONST_CGSM_SOLAR_MASS 
               $GSL_CONST_CGSM_BOHR_RADIUS 
               $GSL_CONST_CGSM_NEWTON 
               $GSL_CONST_CGSM_DYNE 
               $GSL_CONST_CGSM_JOULE 
               $GSL_CONST_CGSM_ERG 
               $GSL_CONST_CGSM_STEFAN_BOLTZMANN_CONSTANT 
               $GSL_CONST_CGSM_THOMSON_CROSS_SECTION 
               /;
@EXPORT_mks   = qw/
               $GSL_CONST_MKS_SPEED_OF_LIGHT 
               $GSL_CONST_MKS_GRAVITATIONAL_CONSTANT 
               $GSL_CONST_MKS_PLANCKS_CONSTANT_H 
               $GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR 
               $GSL_CONST_MKS_ASTRONOMICAL_UNIT 
               $GSL_CONST_MKS_LIGHT_YEAR 
               $GSL_CONST_MKS_PARSEC 
               $GSL_CONST_MKS_GRAV_ACCEL 
               $GSL_CONST_MKS_ELECTRON_VOLT 
               $GSL_CONST_MKS_MASS_ELECTRON 
               $GSL_CONST_MKS_MASS_MUON 
               $GSL_CONST_MKS_MASS_PROTON 
               $GSL_CONST_MKS_MASS_NEUTRON 
               $GSL_CONST_MKS_RYDBERG 
               $GSL_CONST_MKS_BOLTZMANN 
               $GSL_CONST_MKS_BOHR_MAGNETON 
               $GSL_CONST_MKS_NUCLEAR_MAGNETON 
               $GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT 
               $GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT 
               $GSL_CONST_MKS_MOLAR_GAS 
               $GSL_CONST_MKS_STANDARD_GAS_VOLUME 
               $GSL_CONST_MKS_MINUTE 
               $GSL_CONST_MKS_HOUR 
               $GSL_CONST_MKS_DAY 
               $GSL_CONST_MKS_WEEK 
               $GSL_CONST_MKS_INCH 
               $GSL_CONST_MKS_FOOT 
               $GSL_CONST_MKS_YARD 
               $GSL_CONST_MKS_MILE 
               $GSL_CONST_MKS_NAUTICAL_MILE 
               $GSL_CONST_MKS_FATHOM 
               $GSL_CONST_MKS_MIL 
               $GSL_CONST_MKS_POINT 
               $GSL_CONST_MKS_TEXPOINT 
               $GSL_CONST_MKS_MICRON 
               $GSL_CONST_MKS_ANGSTROM 
               $GSL_CONST_MKS_HECTARE 
               $GSL_CONST_MKS_ACRE 
               $GSL_CONST_MKS_BARN 
               $GSL_CONST_MKS_LITER 
               $GSL_CONST_MKS_US_GALLON 
               $GSL_CONST_MKS_QUART 
               $GSL_CONST_MKS_PINT 
               $GSL_CONST_MKS_CUP 
               $GSL_CONST_MKS_FLUID_OUNCE 
               $GSL_CONST_MKS_TABLESPOON 
               $GSL_CONST_MKS_TEASPOON 
               $GSL_CONST_MKS_CANADIAN_GALLON 
               $GSL_CONST_MKS_UK_GALLON 
               $GSL_CONST_MKS_MILES_PER_HOUR 
               $GSL_CONST_MKS_KILOMETERS_PER_HOUR 
               $GSL_CONST_MKS_KNOT 
               $GSL_CONST_MKS_POUND_MASS 
               $GSL_CONST_MKS_OUNCE_MASS 
               $GSL_CONST_MKS_TON 
               $GSL_CONST_MKS_METRIC_TON 
               $GSL_CONST_MKS_UK_TON 
               $GSL_CONST_MKS_TROY_OUNCE 
               $GSL_CONST_MKS_CARAT 
               $GSL_CONST_MKS_UNIFIED_ATOMIC_MASS 
               $GSL_CONST_MKS_GRAM_FORCE 
               $GSL_CONST_MKS_POUND_FORCE 
               $GSL_CONST_MKS_KILOPOUND_FORCE 
               $GSL_CONST_MKS_POUNDAL 
               $GSL_CONST_MKS_CALORIE 
               $GSL_CONST_MKS_BTU 
               $GSL_CONST_MKS_THERM 
               $GSL_CONST_MKS_HORSEPOWER 
               $GSL_CONST_MKS_BAR 
               $GSL_CONST_MKS_STD_ATMOSPHERE 
               $GSL_CONST_MKS_TORR 
               $GSL_CONST_MKS_METER_OF_MERCURY 
               $GSL_CONST_MKS_INCH_OF_MERCURY 
               $GSL_CONST_MKS_INCH_OF_WATER 
               $GSL_CONST_MKS_PSI 
               $GSL_CONST_MKS_POISE 
               $GSL_CONST_MKS_STOKES 
               $GSL_CONST_MKS_FARADAY 
               $GSL_CONST_MKS_ELECTRON_CHARGE 
               $GSL_CONST_MKS_GAUSS 
               $GSL_CONST_MKS_STILB 
               $GSL_CONST_MKS_LUMEN 
               $GSL_CONST_MKS_LUX 
               $GSL_CONST_MKS_PHOT 
               $GSL_CONST_MKS_FOOTCANDLE 
               $GSL_CONST_MKS_LAMBERT 
               $GSL_CONST_MKS_FOOTLAMBERT 
               $GSL_CONST_MKS_CURIE 
               $GSL_CONST_MKS_ROENTGEN 
               $GSL_CONST_MKS_RAD 
               $GSL_CONST_MKS_SOLAR_MASS 
               $GSL_CONST_MKS_BOHR_RADIUS 
               $GSL_CONST_MKS_NEWTON 
               $GSL_CONST_MKS_DYNE 
               $GSL_CONST_MKS_JOULE 
               $GSL_CONST_MKS_ERG 
               $GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT 
               $GSL_CONST_MKS_THOMSON_CROSS_SECTION 
               $GSL_CONST_MKS_VACUUM_PERMITTIVITY 
               $GSL_CONST_MKS_VACUUM_PERMEABILITY 
               $GSL_CONST_MKS_DEBYE 
               /;
@EXPORT_mksa  = qw/
               $GSL_CONST_MKSA_SPEED_OF_LIGHT 
               $GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT 
               $GSL_CONST_MKSA_PLANCKS_CONSTANT_H 
               $GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR 
               $GSL_CONST_MKSA_ASTRONOMICAL_UNIT 
               $GSL_CONST_MKSA_LIGHT_YEAR 
               $GSL_CONST_MKSA_PARSEC 
               $GSL_CONST_MKSA_GRAV_ACCEL 
               $GSL_CONST_MKSA_ELECTRON_VOLT 
               $GSL_CONST_MKSA_MASS_ELECTRON 
               $GSL_CONST_MKSA_MASS_MUON 
               $GSL_CONST_MKSA_MASS_PROTON 
               $GSL_CONST_MKSA_MASS_NEUTRON 
               $GSL_CONST_MKSA_RYDBERG 
               $GSL_CONST_MKSA_BOLTZMANN 
               $GSL_CONST_MKSA_BOHR_MAGNETON 
               $GSL_CONST_MKSA_NUCLEAR_MAGNETON 
               $GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT 
               $GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT 
               $GSL_CONST_MKSA_MOLAR_GAS 
               $GSL_CONST_MKSA_STANDARD_GAS_VOLUME 
               $GSL_CONST_MKSA_MINUTE 
               $GSL_CONST_MKSA_HOUR 
               $GSL_CONST_MKSA_DAY 
               $GSL_CONST_MKSA_WEEK 
               $GSL_CONST_MKSA_INCH 
               $GSL_CONST_MKSA_FOOT 
               $GSL_CONST_MKSA_YARD 
               $GSL_CONST_MKSA_MILE 
               $GSL_CONST_MKSA_NAUTICAL_MILE 
               $GSL_CONST_MKSA_FATHOM 
               $GSL_CONST_MKSA_MIL 
               $GSL_CONST_MKSA_POINT 
               $GSL_CONST_MKSA_TEXPOINT 
               $GSL_CONST_MKSA_MICRON 
               $GSL_CONST_MKSA_ANGSTROM 
               $GSL_CONST_MKSA_HECTARE 
               $GSL_CONST_MKSA_ACRE 
               $GSL_CONST_MKSA_BARN 
               $GSL_CONST_MKSA_LITER 
               $GSL_CONST_MKSA_US_GALLON 
               $GSL_CONST_MKSA_QUART 
               $GSL_CONST_MKSA_PINT 
               $GSL_CONST_MKSA_CUP 
               $GSL_CONST_MKSA_FLUID_OUNCE 
               $GSL_CONST_MKSA_TABLESPOON 
               $GSL_CONST_MKSA_TEASPOON 
               $GSL_CONST_MKSA_CANADIAN_GALLON 
               $GSL_CONST_MKSA_UK_GALLON 
               $GSL_CONST_MKSA_MILES_PER_HOUR 
               $GSL_CONST_MKSA_KILOMETERS_PER_HOUR 
               $GSL_CONST_MKSA_KNOT 
               $GSL_CONST_MKSA_POUND_MASS 
               $GSL_CONST_MKSA_OUNCE_MASS 
               $GSL_CONST_MKSA_TON 
               $GSL_CONST_MKSA_METRIC_TON 
               $GSL_CONST_MKSA_UK_TON 
               $GSL_CONST_MKSA_TROY_OUNCE 
               $GSL_CONST_MKSA_CARAT 
               $GSL_CONST_MKSA_UNIFIED_ATOMIC_MASS 
               $GSL_CONST_MKSA_GRAM_FORCE 
               $GSL_CONST_MKSA_POUND_FORCE 
               $GSL_CONST_MKSA_KILOPOUND_FORCE 
               $GSL_CONST_MKSA_POUNDAL 
               $GSL_CONST_MKSA_CALORIE 
               $GSL_CONST_MKSA_BTU 
               $GSL_CONST_MKSA_THERM 
               $GSL_CONST_MKSA_HORSEPOWER 
               $GSL_CONST_MKSA_BAR 
               $GSL_CONST_MKSA_STD_ATMOSPHERE 
               $GSL_CONST_MKSA_TORR 
               $GSL_CONST_MKSA_METER_OF_MERCURY 
               $GSL_CONST_MKSA_INCH_OF_MERCURY 
               $GSL_CONST_MKSA_INCH_OF_WATER 
               $GSL_CONST_MKSA_PSI 
               $GSL_CONST_MKSA_POISE 
               $GSL_CONST_MKSA_STOKES 
               $GSL_CONST_MKSA_FARADAY 
               $GSL_CONST_MKSA_ELECTRON_CHARGE 
               $GSL_CONST_MKSA_GAUSS 
               $GSL_CONST_MKSA_STILB 
               $GSL_CONST_MKSA_LUMEN 
               $GSL_CONST_MKSA_LUX 
               $GSL_CONST_MKSA_PHOT 
               $GSL_CONST_MKSA_FOOTCANDLE 
               $GSL_CONST_MKSA_LAMBERT 
               $GSL_CONST_MKSA_FOOTLAMBERT 
               $GSL_CONST_MKSA_CURIE 
               $GSL_CONST_MKSA_ROENTGEN 
               $GSL_CONST_MKSA_RAD 
               $GSL_CONST_MKSA_SOLAR_MASS 
               $GSL_CONST_MKSA_BOHR_RADIUS 
               $GSL_CONST_MKSA_NEWTON 
               $GSL_CONST_MKSA_DYNE 
               $GSL_CONST_MKSA_JOULE 
               $GSL_CONST_MKSA_ERG 
               $GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT 
               $GSL_CONST_MKSA_THOMSON_CROSS_SECTION 
               $GSL_CONST_MKSA_VACUUM_PERMITTIVITY 
               $GSL_CONST_MKSA_VACUUM_PERMEABILITY 
               $GSL_CONST_MKSA_DEBYE 
               /;
@EXPORT_num = qw/
               $GSL_CONST_NUM_FINE_STRUCTURE 
               $GSL_CONST_NUM_AVOGADRO 
               $GSL_CONST_NUM_YOTTA 
               $GSL_CONST_NUM_ZETTA 
               $GSL_CONST_NUM_EXA 
               $GSL_CONST_NUM_PETA 
               $GSL_CONST_NUM_TERA 
               $GSL_CONST_NUM_GIGA 
               $GSL_CONST_NUM_MEGA 
               $GSL_CONST_NUM_KILO 
               $GSL_CONST_NUM_MILLI 
               $GSL_CONST_NUM_MICRO 
               $GSL_CONST_NUM_NANO 
               $GSL_CONST_NUM_PICO 
               $GSL_CONST_NUM_FEMTO 
               $GSL_CONST_NUM_ATTO 
               $GSL_CONST_NUM_ZEPTO 
               $GSL_CONST_NUM_YOCTO 
             /;
@EXPORT_OK = ( @EXPORT_cgs, @EXPORT_cgsm, @EXPORT_mks, @EXPORT_mksa, @EXPORT_num, @EXPORT_math);
%EXPORT_TAGS = ( 
                all     => [ @EXPORT_OK   ],
                cgs     => [ @EXPORT_cgs  ], 
                cgsm    => [ @EXPORT_cgsm ], 
                mks     => [ @EXPORT_mks  ], 
                mksa    => [ @EXPORT_mksa ], 
                num     => [ @EXPORT_num  ], 
                math    => [ @EXPORT_math ],
               );

__END__

=head1 NAME

Math::GSL::Const - Constants 

=head1 SYNOPSIS

    use Math::GSL::Const qw/:all/;
    print "The Euler-Mascheroni Constant is $M_EULER\n";

There are many constants in this module, which are split into six subcategories a.k.a tags:

=head2 TAGS

=over 2

=item * cgs 

=back

=over 4

=item *   $GSL_CONST_CGS_SPEED_OF_LIGHT 

=item *   $GSL_CONST_CGS_GRAVITATIONAL_CONSTANT 

=item *   $GSL_CONST_CGS_PLANCKS_CONSTANT_H 

=item *   $GSL_CONST_CGS_PLANCKS_CONSTANT_HBAR 

=item *   $GSL_CONST_CGS_ASTRONOMICAL_UNIT 

=item *   $GSL_CONST_CGS_LIGHT_YEAR 

=item *   $GSL_CONST_CGS_PARSEC 

=item *   $GSL_CONST_CGS_GRAV_ACCEL 

=item *   $GSL_CONST_CGS_ELECTRON_VOLT 

=item *   $GSL_CONST_CGS_MASS_ELECTRON 

=item *   $GSL_CONST_CGS_MASS_MUON 

=item *   $GSL_CONST_CGS_MASS_PROTON 

=item *   $GSL_CONST_CGS_MASS_NEUTRON 

=item *   $GSL_CONST_CGS_RYDBERG 

=item *   $GSL_CONST_CGS_BOLTZMANN 

=item *   $GSL_CONST_CGS_BOHR_MAGNETON 

=item *   $GSL_CONST_CGS_NUCLEAR_MAGNETON 

=item *   $GSL_CONST_CGS_ELECTRON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_CGS_PROTON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_CGS_MOLAR_GAS 

=item *   $GSL_CONST_CGS_STANDARD_GAS_VOLUME 

=item *   $GSL_CONST_CGS_MINUTE 

=item *   $GSL_CONST_CGS_HOUR 

=item *   $GSL_CONST_CGS_DAY 

=item *   $GSL_CONST_CGS_WEEK 

=item *   $GSL_CONST_CGS_INCH 

=item *   $GSL_CONST_CGS_FOOT 

=item *   $GSL_CONST_CGS_YARD 

=item *   $GSL_CONST_CGS_MILE 

=item *   $GSL_CONST_CGS_NAUTICAL_MILE 

=item *   $GSL_CONST_CGS_FATHOM 

=item *   $GSL_CONST_CGS_MIL 

=item *   $GSL_CONST_CGS_POINT 

=item *   $GSL_CONST_CGS_TEXPOINT 

=item *   $GSL_CONST_CGS_MICRON 

=item *   $GSL_CONST_CGS_ANGSTROM 

=item *   $GSL_CONST_CGS_HECTARE 

=item *   $GSL_CONST_CGS_ACRE 

=item *   $GSL_CONST_CGS_BARN 

=item *   $GSL_CONST_CGS_LITER 

=item *   $GSL_CONST_CGS_US_GALLON 

=item *   $GSL_CONST_CGS_QUART 

=item *   $GSL_CONST_CGS_PINT 

=item *   $GSL_CONST_CGS_CUP 

=item *   $GSL_CONST_CGS_FLUID_OUNCE 

=item *   $GSL_CONST_CGS_TABLESPOON 

=item *   $GSL_CONST_CGS_TEASPOON 

=item *   $GSL_CONST_CGS_CANADIAN_GALLON 

=item *   $GSL_CONST_CGS_UK_GALLON 

=item *   $GSL_CONST_CGS_MILES_PER_HOUR 

=item *   $GSL_CONST_CGS_KILOMETERS_PER_HOUR 

=item *   $GSL_CONST_CGS_KNOT 

=item *   $GSL_CONST_CGS_POUND_MASS 

=item *   $GSL_CONST_CGS_OUNCE_MASS 

=item *   $GSL_CONST_CGS_TON 

=item *   $GSL_CONST_CGS_METRIC_TON 

=item *   $GSL_CONST_CGS_UK_TON 

=item *   $GSL_CONST_CGS_TROY_OUNCE 

=item *   $GSL_CONST_CGS_CARAT 

=item *   $GSL_CONST_CGS_UNIFIED_ATOMIC_MASS 

=item *   $GSL_CONST_CGS_GRAM_FORCE 

=item *   $GSL_CONST_CGS_POUND_FORCE 

=item *   $GSL_CONST_CGS_KILOPOUND_FORCE 

=item *   $GSL_CONST_CGS_POUNDAL 

=item *   $GSL_CONST_CGS_CALORIE 

=item *   $GSL_CONST_CGS_BTU 

=item *   $GSL_CONST_CGS_THERM 

=item *   $GSL_CONST_CGS_HORSEPOWER 

=item *   $GSL_CONST_CGS_BAR 

=item *   $GSL_CONST_CGS_STD_ATMOSPHERE 

=item *   $GSL_CONST_CGS_TORR 

=item *   $GSL_CONST_CGS_METER_OF_MERCURY 

=item *   $GSL_CONST_CGS_INCH_OF_MERCURY 

=item *   $GSL_CONST_CGS_INCH_OF_WATER 

=item *   $GSL_CONST_CGS_PSI 

=item *   $GSL_CONST_CGS_POISE 

=item *   $GSL_CONST_CGS_STOKES 

=item *   $GSL_CONST_CGS_FARADAY 

=item *   $GSL_CONST_CGS_ELECTRON_CHARGE 

=item *   $GSL_CONST_CGS_GAUSS 

=item *   $GSL_CONST_CGS_STILB 

=item *   $GSL_CONST_CGS_LUMEN 

=item *   $GSL_CONST_CGS_LUX 

=item *   $GSL_CONST_CGS_PHOT 

=item *   $GSL_CONST_CGS_FOOTCANDLE 

=item *   $GSL_CONST_CGS_LAMBERT 

=item *   $GSL_CONST_CGS_FOOTLAMBERT 

=item *   $GSL_CONST_CGS_CURIE 

=item *   $GSL_CONST_CGS_ROENTGEN 

=item *   $GSL_CONST_CGS_RAD 

=item *   $GSL_CONST_CGS_SOLAR_MASS 

=item *   $GSL_CONST_CGS_BOHR_RADIUS 

=item *   $GSL_CONST_CGS_NEWTON 

=item *   $GSL_CONST_CGS_DYNE 

=item *   $GSL_CONST_CGS_JOULE 

=item *   $GSL_CONST_CGS_ERG 

=item *   $GSL_CONST_CGS_STEFAN_BOLTZMANN_CONSTANT 

=item *   $GSL_CONST_CGS_THOMSON_CROSS_SECTION 

=back

=over 2

=item * cgsm  - CGSM system (centimeters, grams, seconds, gauss)

=back

=over 4

=item *   $GSL_CONST_CGSM_SPEED_OF_LIGHT 

=item *   $GSL_CONST_CGSM_GRAVITATIONAL_CONSTANT 

=item *   $GSL_CONST_CGSM_PLANCKS_CONSTANT_H 

=item *   $GSL_CONST_CGSM_PLANCKS_CONSTANT_HBAR 

=item *   $GSL_CONST_CGSM_ASTRONOMICAL_UNIT 

=item *   $GSL_CONST_CGSM_LIGHT_YEAR 

=item *   $GSL_CONST_CGSM_PARSEC 

=item *   $GSL_CONST_CGSM_GRAV_ACCEL 

=item *   $GSL_CONST_CGSM_ELECTRON_VOLT 

=item *   $GSL_CONST_CGSM_MASS_ELECTRON 

=item *   $GSL_CONST_CGSM_MASS_MUON 

=item *   $GSL_CONST_CGSM_MASS_PROTON 

=item *   $GSL_CONST_CGSM_MASS_NEUTRON 

=item *   $GSL_CONST_CGSM_RYDBERG 

=item *   $GSL_CONST_CGSM_BOLTZMANN 

=item *   $GSL_CONST_CGSM_BOHR_MAGNETON 

=item *   $GSL_CONST_CGSM_NUCLEAR_MAGNETON 

=item *   $GSL_CONST_CGSM_ELECTRON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_CGSM_PROTON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_CGSM_MOLAR_GAS 

=item *   $GSL_CONST_CGSM_STANDARD_GAS_VOLUME 

=item *   $GSL_CONST_CGSM_MINUTE 

=item *   $GSL_CONST_CGSM_HOUR 

=item *   $GSL_CONST_CGSM_DAY 

=item *   $GSL_CONST_CGSM_WEEK 

=item *   $GSL_CONST_CGSM_INCH 

=item *   $GSL_CONST_CGSM_FOOT 

=item *   $GSL_CONST_CGSM_YARD 

=item *   $GSL_CONST_CGSM_MILE 

=item *   $GSL_CONST_CGSM_NAUTICAL_MILE 

=item *   $GSL_CONST_CGSM_FATHOM 

=item *   $GSL_CONST_CGSM_MIL 

=item *   $GSL_CONST_CGSM_POINT 

=item *   $GSL_CONST_CGSM_TEXPOINT 

=item *   $GSL_CONST_CGSM_MICRON 

=item *   $GSL_CONST_CGSM_ANGSTROM 

=item *   $GSL_CONST_CGSM_HECTARE 

=item *   $GSL_CONST_CGSM_ACRE 

=item *   $GSL_CONST_CGSM_BARN 

=item *   $GSL_CONST_CGSM_LITER 

=item *   $GSL_CONST_CGSM_US_GALLON 

=item *   $GSL_CONST_CGSM_QUART 

=item *   $GSL_CONST_CGSM_PINT 

=item *   $GSL_CONST_CGSM_CUP 

=item *   $GSL_CONST_CGSM_FLUID_OUNCE 

=item *   $GSL_CONST_CGSM_TABLESPOON 

=item *   $GSL_CONST_CGSM_TEASPOON 

=item *   $GSL_CONST_CGSM_CANADIAN_GALLON 

=item *   $GSL_CONST_CGSM_UK_GALLON 

=item *   $GSL_CONST_CGSM_MILES_PER_HOUR 

=item *   $GSL_CONST_CGSM_KILOMETERS_PER_HOUR 

=item *   $GSL_CONST_CGSM_KNOT 

=item *   $GSL_CONST_CGSM_POUND_MASS 

=item *   $GSL_CONST_CGSM_OUNCE_MASS 

=item *   $GSL_CONST_CGSM_TON 

=item *   $GSL_CONST_CGSM_METRIC_TON 

=item *   $GSL_CONST_CGSM_UK_TON 

=item *   $GSL_CONST_CGSM_TROY_OUNCE 

=item *   $GSL_CONST_CGSM_CARAT 

=item *   $GSL_CONST_CGSM_UNIFIED_ATOMIC_MASS 

=item *   $GSL_CONST_CGSM_GRAM_FORCE 

=item *   $GSL_CONST_CGSM_POUND_FORCE 

=item *   $GSL_CONST_CGSM_KILOPOUND_FORCE 

=item *   $GSL_CONST_CGSM_POUNDAL 

=item *   $GSL_CONST_CGSM_CALORIE 

=item *   $GSL_CONST_CGSM_BTU 

=item *   $GSL_CONST_CGSM_THERM 

=item *   $GSL_CONST_CGSM_HORSEPOWER 

=item *   $GSL_CONST_CGSM_BAR 

=item *   $GSL_CONST_CGSM_STD_ATMOSPHERE 

=item *   $GSL_CONST_CGSM_TORR 

=item *   $GSL_CONST_CGSM_METER_OF_MERCURY 

=item *   $GSL_CONST_CGSM_INCH_OF_MERCURY 

=item *   $GSL_CONST_CGSM_INCH_OF_WATER 

=item *   $GSL_CONST_CGSM_PSI 

=item *   $GSL_CONST_CGSM_POISE 

=item *   $GSL_CONST_CGSM_STOKES 

=item *   $GSL_CONST_CGSM_FARADAY 

=item *   $GSL_CONST_CGSM_ELECTRON_CHARGE 

=item *   $GSL_CONST_CGSM_GAUSS 

=item *   $GSL_CONST_CGSM_STILB 

=item *   $GSL_CONST_CGSM_LUMEN 

=item *   $GSL_CONST_CGSM_LUX 

=item *   $GSL_CONST_CGSM_PHOT 

=item *   $GSL_CONST_CGSM_FOOTCANDLE 

=item *   $GSL_CONST_CGSM_LAMBERT 

=item *   $GSL_CONST_CGSM_FOOTLAMBERT 

=item *   $GSL_CONST_CGSM_CURIE 

=item *   $GSL_CONST_CGSM_ROENTGEN 

=item *   $GSL_CONST_CGSM_RAD 

=item *   $GSL_CONST_CGSM_SOLAR_MASS 

=item *   $GSL_CONST_CGSM_BOHR_RADIUS 

=item *   $GSL_CONST_CGSM_NEWTON 

=item *   $GSL_CONST_CGSM_DYNE 

=item *   $GSL_CONST_CGSM_JOULE 

=item *   $GSL_CONST_CGSM_ERG 

=item *   $GSL_CONST_CGSM_STEFAN_BOLTZMANN_CONSTANT 

=item *   $GSL_CONST_CGSM_THOMSON_CROSS_SECTION 

=back

=over 2

=item * mks  

=back

=over 4

=item *   $GSL_CONST_MKS_SPEED_OF_LIGHT 

=item *   $GSL_CONST_MKS_GRAVITATIONAL_CONSTANT 

=item *   $GSL_CONST_MKS_PLANCKS_CONSTANT_H 

=item *   $GSL_CONST_MKS_PLANCKS_CONSTANT_HBAR 

=item *   $GSL_CONST_MKS_ASTRONOMICAL_UNIT 

=item *   $GSL_CONST_MKS_LIGHT_YEAR 

=item *   $GSL_CONST_MKS_PARSEC 

=item *   $GSL_CONST_MKS_GRAV_ACCEL 

=item *   $GSL_CONST_MKS_ELECTRON_VOLT 

=item *   $GSL_CONST_MKS_MASS_ELECTRON 

=item *   $GSL_CONST_MKS_MASS_MUON 

=item *   $GSL_CONST_MKS_MASS_PROTON 

=item *   $GSL_CONST_MKS_MASS_NEUTRON 

=item *   $GSL_CONST_MKS_RYDBERG 

=item *   $GSL_CONST_MKS_BOLTZMANN 

=item *   $GSL_CONST_MKS_BOHR_MAGNETON 

=item *   $GSL_CONST_MKS_NUCLEAR_MAGNETON 

=item *   $GSL_CONST_MKS_ELECTRON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_MKS_PROTON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_MKS_MOLAR_GAS 

=item *   $GSL_CONST_MKS_STANDARD_GAS_VOLUME 

=item *   $GSL_CONST_MKS_MINUTE 

=item *   $GSL_CONST_MKS_HOUR 

=item *   $GSL_CONST_MKS_DAY 

=item *   $GSL_CONST_MKS_WEEK 

=item *   $GSL_CONST_MKS_INCH 

=item *   $GSL_CONST_MKS_FOOT 

=item *   $GSL_CONST_MKS_YARD 

=item *   $GSL_CONST_MKS_MILE 

=item *   $GSL_CONST_MKS_NAUTICAL_MILE 

=item *   $GSL_CONST_MKS_FATHOM 

=item *   $GSL_CONST_MKS_MIL 

=item *   $GSL_CONST_MKS_POINT 

=item *   $GSL_CONST_MKS_TEXPOINT 

=item *   $GSL_CONST_MKS_MICRON 

=item *   $GSL_CONST_MKS_ANGSTROM 

=item *   $GSL_CONST_MKS_HECTARE 

=item *   $GSL_CONST_MKS_ACRE 

=item *   $GSL_CONST_MKS_BARN 

=item *   $GSL_CONST_MKS_LITER 

=item *   $GSL_CONST_MKS_US_GALLON 

=item *   $GSL_CONST_MKS_QUART 

=item *   $GSL_CONST_MKS_PINT 

=item *   $GSL_CONST_MKS_CUP 

=item *   $GSL_CONST_MKS_FLUID_OUNCE 

=item *   $GSL_CONST_MKS_TABLESPOON 

=item *   $GSL_CONST_MKS_TEASPOON 

=item *   $GSL_CONST_MKS_CANADIAN_GALLON 

=item *   $GSL_CONST_MKS_UK_GALLON 

=item *   $GSL_CONST_MKS_MILES_PER_HOUR 

=item *   $GSL_CONST_MKS_KILOMETERS_PER_HOUR 

=item *   $GSL_CONST_MKS_KNOT 

=item *   $GSL_CONST_MKS_POUND_MASS 

=item *   $GSL_CONST_MKS_OUNCE_MASS 

=item *   $GSL_CONST_MKS_TON 

=item *   $GSL_CONST_MKS_METRIC_TON 

=item *   $GSL_CONST_MKS_UK_TON 

=item *   $GSL_CONST_MKS_TROY_OUNCE 

=item *   $GSL_CONST_MKS_CARAT 

=item *   $GSL_CONST_MKS_UNIFIED_ATOMIC_MASS 

=item *   $GSL_CONST_MKS_GRAM_FORCE 

=item *   $GSL_CONST_MKS_POUND_FORCE 

=item *   $GSL_CONST_MKS_KILOPOUND_FORCE 

=item *   $GSL_CONST_MKS_POUNDAL 

=item *   $GSL_CONST_MKS_CALORIE 

=item *   $GSL_CONST_MKS_BTU 

=item *   $GSL_CONST_MKS_THERM 

=item *   $GSL_CONST_MKS_HORSEPOWER 

=item *   $GSL_CONST_MKS_BAR 

=item *   $GSL_CONST_MKS_STD_ATMOSPHERE 

=item *   $GSL_CONST_MKS_TORR 

=item *   $GSL_CONST_MKS_METER_OF_MERCURY 

=item *   $GSL_CONST_MKS_INCH_OF_MERCURY 

=item *   $GSL_CONST_MKS_INCH_OF_WATER 

=item *   $GSL_CONST_MKS_PSI 

=item *   $GSL_CONST_MKS_POISE 

=item *   $GSL_CONST_MKS_STOKES 

=item *   $GSL_CONST_MKS_FARADAY 

=item *   $GSL_CONST_MKS_ELECTRON_CHARGE 

=item *   $GSL_CONST_MKS_GAUSS 

=item *   $GSL_CONST_MKS_STILB 

=item *   $GSL_CONST_MKS_LUMEN 

=item *   $GSL_CONST_MKS_LUX 

=item *   $GSL_CONST_MKS_PHOT 

=item *   $GSL_CONST_MKS_FOOTCANDLE 

=item *   $GSL_CONST_MKS_LAMBERT 

=item *   $GSL_CONST_MKS_FOOTLAMBERT 

=item *   $GSL_CONST_MKS_CURIE 

=item *   $GSL_CONST_MKS_ROENTGEN 

=item *   $GSL_CONST_MKS_RAD 

=item *   $GSL_CONST_MKS_SOLAR_MASS 

=item *   $GSL_CONST_MKS_BOHR_RADIUS 

=item *   $GSL_CONST_MKS_NEWTON 

=item *   $GSL_CONST_MKS_DYNE 

=item *   $GSL_CONST_MKS_JOULE 

=item *   $GSL_CONST_MKS_ERG 

=item *   $GSL_CONST_MKS_STEFAN_BOLTZMANN_CONSTANT 

=item *   $GSL_CONST_MKS_THOMSON_CROSS_SECTION 

=item *   $GSL_CONST_MKS_VACUUM_PERMITTIVITY 

=item *   $GSL_CONST_MKS_VACUUM_PERMEABILITY 

=item *   $GSL_CONST_MKS_DEBYE 

=back

=over 2
 
=item * mksa  - Standard MKSA system (meters, kilograms, seconds, amperes)

=back

=over 4

=item *   $GSL_CONST_MKSA_SPEED_OF_LIGHT 

=item *   $GSL_CONST_MKSA_GRAVITATIONAL_CONSTANT 

=item *   $GSL_CONST_MKSA_PLANCKS_CONSTANT_H 

=item *   $GSL_CONST_MKSA_PLANCKS_CONSTANT_HBAR 

=item *   $GSL_CONST_MKSA_ASTRONOMICAL_UNIT 

=item *   $GSL_CONST_MKSA_LIGHT_YEAR 

=item *   $GSL_CONST_MKSA_PARSEC 

=item *   $GSL_CONST_MKSA_GRAV_ACCEL 

=item *   $GSL_CONST_MKSA_ELECTRON_VOLT 

=item *   $GSL_CONST_MKSA_MASS_ELECTRON 

=item *   $GSL_CONST_MKSA_MASS_MUON 

=item *   $GSL_CONST_MKSA_MASS_PROTON 

=item *   $GSL_CONST_MKSA_MASS_NEUTRON 

=item *   $GSL_CONST_MKSA_RYDBERG 

=item *   $GSL_CONST_MKSA_BOLTZMANN 

=item *   $GSL_CONST_MKSA_BOHR_MAGNETON 

=item *   $GSL_CONST_MKSA_NUCLEAR_MAGNETON 

=item *   $GSL_CONST_MKSA_ELECTRON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_MKSA_PROTON_MAGNETIC_MOMENT 

=item *   $GSL_CONST_MKSA_MOLAR_GAS 

=item *   $GSL_CONST_MKSA_STANDARD_GAS_VOLUME 

=item *   $GSL_CONST_MKSA_MINUTE 

=item *   $GSL_CONST_MKSA_HOUR 

=item *   $GSL_CONST_MKSA_DAY 

=item *   $GSL_CONST_MKSA_WEEK 

=item *   $GSL_CONST_MKSA_INCH 

=item *   $GSL_CONST_MKSA_FOOT 

=item *   $GSL_CONST_MKSA_YARD 

=item *   $GSL_CONST_MKSA_MILE 

=item *   $GSL_CONST_MKSA_NAUTICAL_MILE 

=item *   $GSL_CONST_MKSA_FATHOM 

=item *   $GSL_CONST_MKSA_MIL 

=item *   $GSL_CONST_MKSA_POINT 

=item *   $GSL_CONST_MKSA_TEXPOINT 

=item *   $GSL_CONST_MKSA_MICRON 

=item *   $GSL_CONST_MKSA_ANGSTROM 

=item *   $GSL_CONST_MKSA_HECTARE 

=item *   $GSL_CONST_MKSA_ACRE 

=item *   $GSL_CONST_MKSA_BARN 

=item *   $GSL_CONST_MKSA_LITER 

=item *   $GSL_CONST_MKSA_US_GALLON 

=item *   $GSL_CONST_MKSA_QUART 

=item *   $GSL_CONST_MKSA_PINT 

=item *   $GSL_CONST_MKSA_CUP 

=item *   $GSL_CONST_MKSA_FLUID_OUNCE 

=item *   $GSL_CONST_MKSA_TABLESPOON 

=item *   $GSL_CONST_MKSA_TEASPOON 

=item *   $GSL_CONST_MKSA_CANADIAN_GALLON 

=item *   $GSL_CONST_MKSA_UK_GALLON 

=item *   $GSL_CONST_MKSA_MILES_PER_HOUR 

=item *   $GSL_CONST_MKSA_KILOMETERS_PER_HOUR 

=item *   $GSL_CONST_MKSA_KNOT 

=item *   $GSL_CONST_MKSA_POUND_MASS 

=item *   $GSL_CONST_MKSA_OUNCE_MASS 

=item *   $GSL_CONST_MKSA_TON 

=item *   $GSL_CONST_MKSA_METRIC_TON 

=item *   $GSL_CONST_MKSA_UK_TON 

=item *   $GSL_CONST_MKSA_TROY_OUNCE 

=item *   $GSL_CONST_MKSA_CARAT 

=item *   $GSL_CONST_MKSA_UNIFIED_ATOMIC_MASS 

=item *   $GSL_CONST_MKSA_GRAM_FORCE 

=item *   $GSL_CONST_MKSA_POUND_FORCE 

=item *   $GSL_CONST_MKSA_KILOPOUND_FORCE 

=item *   $GSL_CONST_MKSA_POUNDAL 

=item *   $GSL_CONST_MKSA_CALORIE 

=item *   $GSL_CONST_MKSA_BTU 

=item *   $GSL_CONST_MKSA_THERM 

=item *   $GSL_CONST_MKSA_HORSEPOWER 

=item *   $GSL_CONST_MKSA_BAR 

=item *   $GSL_CONST_MKSA_STD_ATMOSPHERE 

=item *   $GSL_CONST_MKSA_TORR 

=item *   $GSL_CONST_MKSA_METER_OF_MERCURY 

=item *   $GSL_CONST_MKSA_INCH_OF_MERCURY 

=item *   $GSL_CONST_MKSA_INCH_OF_WATER 

=item *   $GSL_CONST_MKSA_PSI 

=item *   $GSL_CONST_MKSA_POISE 

=item *   $GSL_CONST_MKSA_STOKES 

=item *   $GSL_CONST_MKSA_FARADAY 

=item *   $GSL_CONST_MKSA_ELECTRON_CHARGE 

=item *   $GSL_CONST_MKSA_GAUSS 

=item *   $GSL_CONST_MKSA_STILB 

=item *   $GSL_CONST_MKSA_LUMEN 

=item *   $GSL_CONST_MKSA_LUX 

=item *   $GSL_CONST_MKSA_PHOT 

=item *   $GSL_CONST_MKSA_FOOTCANDLE 

=item *   $GSL_CONST_MKSA_LAMBERT 

=item *   $GSL_CONST_MKSA_FOOTLAMBERT 

=item *   $GSL_CONST_MKSA_CURIE 

=item *   $GSL_CONST_MKSA_ROENTGEN 

=item *   $GSL_CONST_MKSA_RAD 

=item *   $GSL_CONST_MKSA_SOLAR_MASS 

=item *   $GSL_CONST_MKSA_BOHR_RADIUS 

=item *   $GSL_CONST_MKSA_NEWTON 

=item *   $GSL_CONST_MKSA_DYNE 

=item *   $GSL_CONST_MKSA_JOULE 

=item *   $GSL_CONST_MKSA_ERG 

=item *   $GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT 

=item *   $GSL_CONST_MKSA_THOMSON_CROSS_SECTION 

=item *   $GSL_CONST_MKSA_VACUUM_PERMITTIVITY 

=item *   $GSL_CONST_MKSA_VACUUM_PERMEABILITY 

=item *   $GSL_CONST_MKSA_DEBYE 

=back

=over 2

=item * math  - Mathematical 

=back

=over 4

=item *   $M_E - Euler's Constant e

=item *   $M_LOG2E - Log base 2 of e

=item *   $M_LOG10E  - Log base 10 of e

=item *   $M_SQRT2  - Square root of 2

=item *   $M_SQRT1_2  - Square root of 1/2

=item *   $M_SQRT3  - Square root of 3

=item *   $M_PI - Pi

=item *   $M_PI_2 - Pi divided by 2

=item *   $M_PI_4  - Pi divided by 4

=item *   $M_SQRTPI  - Square root of pi

=item *   $M_2_SQRTPI - Two over the square root of pi

=item *   $M_1_PI  - One over pi

=item *   $M_2_PI  - Two over pi

=item *   $M_LN10  - Natural log of 10

=item *   $M_LN2   - Natural log of 2

=item *   $M_LNPI  - Natural log of pi

=item *   $M_EULER  - Euler-Mascheroni Constant 

=back

=over 2

=item *   num - Dimensionless Numbers

=back

=over 4

=item *   $GSL_CONST_NUM_FINE_STRUCTURE 

=item *   $GSL_CONST_NUM_AVOGADRO 

=item *   $GSL_CONST_NUM_YOTTA 

=item *   $GSL_CONST_NUM_ZETTA 

=item *   $GSL_CONST_NUM_EXA 

=item *   $GSL_CONST_NUM_PETA 

=item *   $GSL_CONST_NUM_TERA 

=item *   $GSL_CONST_NUM_GIGA 

=item *   $GSL_CONST_NUM_MEGA 

=item *   $GSL_CONST_NUM_KILO 

=item *   $GSL_CONST_NUM_MILLI 

=item *   $GSL_CONST_NUM_MICRO 

=item *   $GSL_CONST_NUM_NANO 

=item *   $GSL_CONST_NUM_PICO 

=item *   $GSL_CONST_NUM_FEMTO 

=item *   $GSL_CONST_NUM_ATTO 

=item *   $GSL_CONST_NUM_ZEPTO 

=item *   $GSL_CONST_NUM_YOCTO 

=back

Importing the tag C<all> is the same as importing all of these.

=head1 AUTHORS

Jonathan Leto <jonathan@leto.net> and Thierry Moisan <thierry.moisan@gmail.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 Jonathan Leto and Thierry Moisan

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1;
